# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .typescript_automation_config import TypescriptAutomationConfig
    from .action_type import ActionType
    from .activity_schema import ActivitySchema
    from .actor import Actor
    from .actor_identity import ActorIdentity
    from .actor_identity_id import ActorIdentityId
    from .actor_identity_type import ActorIdentityType
    from .agent_hook import AgentHook
    from .agent_hook_input import AgentHookInput
    from .agent_revision import AgentRevision
    from .agent_revision_model import AgentRevisionModel
    from .agent_revision_response_style import AgentRevisionResponseStyle
    from .agent_revision_tool_config_value import AgentRevisionToolConfigValue
    from .agent_target_config import AgentTargetConfig
    from .ai_agent import AiAgent
    from .api_key_auth_type import ApiKeyAuthType
    from .api_key_identity import ApiKeyIdentity
    from .api_key_identity_details import ApiKeyIdentityDetails
    from .automation_hook import AutomationHook
    from .automation_hook_input import AutomationHookInput
    from .automation_target_config import AutomationTargetConfig
    from .bare_input import BareInput
    from .bare_output import BareOutput
    from .baseline import Baseline
    from .batch_create_request import BatchCreateRequest
    from .batch_generate_request import BatchGenerateRequest
    from .billing import Billing
    from .billing_cycle import BillingCycle
    from .billing_cycles import BillingCycles
    from .billing_limits import BillingLimits
    from .billing_usage import BillingUsage
    from .block_config_item_boolean import BlockConfigItemBoolean
    from .block_config_item_json import BlockConfigItemJson
    from .block_config_item_llm import BlockConfigItemLlm
    from .block_config_item_number import BlockConfigItemNumber
    from .block_config_item_number_default_value import BlockConfigItemNumberDefaultValue
    from .block_config_item_number_maximum_value import BlockConfigItemNumberMaximumValue
    from .block_config_item_number_minimum_value import BlockConfigItemNumberMinimumValue
    from .block_config_item_number_value import BlockConfigItemNumberValue
    from .block_config_item_select import BlockConfigItemSelect
    from .block_config_item_text_long import BlockConfigItemTextLong
    from .block_config_item_text_long_value import BlockConfigItemTextLongValue
    from .block_config_item_text_short import BlockConfigItemTextShort
    from .block_input import BlockInput
    from .block_input_block_config_item import BlockInputBlockConfigItem
    from .block_output import BlockOutput
    from .block_output_block_config_item import BlockOutputBlockConfigItem
    from .block_run import BlockRun
    from .block_run_completed import BlockRunCompleted
    from .block_run_completed_data import BlockRunCompletedData
    from .block_run_completed_environment import BlockRunCompletedEnvironment
    from .block_run_failed import BlockRunFailed
    from .block_run_failed_data import BlockRunFailedData
    from .block_run_failed_environment import BlockRunFailedEnvironment
    from .block_run_started import BlockRunStarted
    from .block_run_started_data import BlockRunStartedData
    from .block_run_started_environment import BlockRunStartedEnvironment
    from .block_run_usage import BlockRunUsage
    from .block_state_updated import BlockStateUpdated
    from .block_state_updated_data import BlockStateUpdatedData
    from .block_state_updated_data_update_type import BlockStateUpdatedDataUpdateType
    from .block_state_updated_environment import BlockStateUpdatedEnvironment
    from .body_parse_file_v_2_files_parse_post import BodyParseFileV2FilesParsePost
    from .body_upload_files_to_drive_drive_files_post import BodyUploadFilesToDriveDriveFilesPost
    from .body_upload_private_files_inbox_session_id_files_post import BodyUploadPrivateFilesInboxSessionIdFilesPost
    from .body_upload_pulse_files_stream_pulse_files_stream_post import BodyUploadPulseFilesStreamPulseFilesStreamPost
    from .body_upsert_agent_agents_post import BodyUpsertAgentAgentsPost
    from .cancel_response import CancelResponse
    from .card_display_field import CardDisplayField
    from .channel import Channel
    from .check_box_column import CheckBoxColumn
    from .collection import Collection
    from .collection_config import CollectionConfig
    from .collection_destination import CollectionDestination
    from .collection_view_state_input import CollectionViewStateInput
    from .collection_view_state_input_views_value import CollectionViewStateInputViewsValue
    from .collection_view_state_output import CollectionViewStateOutput
    from .collection_view_state_output_views_value import CollectionViewStateOutputViewsValue
    from .column_type import ColumnType
    from .column_type_base import ColumnTypeBase
    from .condition import Condition
    from .condition_field import ConditionField
    from .condition_operator import ConditionOperator
    from .connect_integration_request import ConnectIntegrationRequest
    from .connect_integration_request_auth_type import ConnectIntegrationRequestAuthType
    from .copilot import Copilot
    from .copilot_config import CopilotConfig
    from .copilot_config_code_theme import CopilotConfigCodeTheme
    from .copilot_config_fab_value import CopilotConfigFabValue
    from .copilot_config_mode import CopilotConfigMode
    from .create_entity_request import CreateEntityRequest
    from .create_integrations_response import CreateIntegrationsResponse
    from .create_pulse_request import CreatePulseRequest
    from .create_pulse_response import CreatePulseResponse
    from .create_tag_response import CreateTagResponse
    from .cron_trigger_config import CronTriggerConfig
    from .cron_trigger_config_action import CronTriggerConfigAction
    from .custom import Custom
    from .daily_usage import DailyUsage
    from .data_type import DataType
    from .date_time_column import DateTimeColumn
    from .default_input import DefaultInput
    from .default_output import DefaultOutput
    from .delete_hook_response import DeleteHookResponse
    from .delete_response import DeleteResponse
    from .delete_trigger_response import DeleteTriggerResponse
    from .delete_view_response import DeleteViewResponse
    from .dependency import Dependency
    from .determined_billing_limits import DeterminedBillingLimits
    from .dimensions import Dimensions
    from .document import Document
    from .document_created_by import DocumentCreatedBy
    from .document_data_value import DocumentDataValue
    from .document_last_updated_by import DocumentLastUpdatedBy
    from .document_response import DocumentResponse
    from .edge_ui import EdgeUi
    from .entity_query_request import EntityQueryRequest
    from .entity_response import EntityResponse
    from .entity_search_request import EntitySearchRequest
    from .entity_search_request_mode import EntitySearchRequestMode
    from .entity_search_request_return_format import EntitySearchRequestReturnFormat
    from .environment import Environment
    from .environment_config import EnvironmentConfig
    from .environment_deployment_config import EnvironmentDeploymentConfig
    from .environment_deployment_config_revision_lookup import EnvironmentDeploymentConfigRevisionLookup
    from .environment_deployment_document import EnvironmentDeploymentDocument
    from .event_version import EventVersion
    from .execute_tool_request import ExecuteToolRequest
    from .execute_tool_response import ExecuteToolResponse
    from .execute_trigger_response import ExecuteTriggerResponse
    from .favor import Favor
    from .favorite_item import FavoriteItem
    from .favorite_ref import FavoriteRef
    from .field_mapping import FieldMapping
    from .file import File
    from .files_attribute import FilesAttribute
    from .files_response import FilesResponse
    from .filter_operator import FilterOperator
    from .filter_type import FilterType
    from .flags import Flags
    from .fluent_query_request import FluentQueryRequest
    from .fluent_query_request_with_item import FluentQueryRequestWithItem
    from .friendly_invoice import FriendlyInvoice
    from .friendly_payment_methods import FriendlyPaymentMethods
    from .generate_ai_suggestion_request import GenerateAiSuggestionRequest
    from .hook_update import HookUpdate
    from .hooks_list_response import HooksListResponse
    from .html_2_text import Html2Text
    from .http import Http
    from .http_validation_error import HttpValidationError
    from .identity import Identity
    from .identity_details import IdentityDetails
    from .identity_types import IdentityTypes
    from .integration import Integration
    from .integration_auth_type import IntegrationAuthType
    from .integration_connection import IntegrationConnection
    from .integration_connection_auth_type import IntegrationConnectionAuthType
    from .integration_connection_integration_type import IntegrationConnectionIntegrationType
    from .integration_with_connections import IntegrationWithConnections
    from .integration_with_connections_id import IntegrationWithConnectionsId
    from .interval import Interval
    from .interval_types import IntervalTypes
    from .invoice import Invoice
    from .invoice_meta import InvoiceMeta
    from .invoice_status import InvoiceStatus
    from .json_column import JsonColumn
    from .kanban_view_input import KanbanViewInput
    from .kanban_view_output import KanbanViewOutput
    from .kanban_view_settings_input import KanbanViewSettingsInput
    from .kanban_view_settings_output import KanbanViewSettingsOutput
    from .legacy_identity import LegacyIdentity
    from .legacy_identity_details import LegacyIdentityDetails
    from .line_item import LineItem
    from .list_tags_response import ListTagsResponse
    from .list_tools_response import ListToolsResponse
    from .list_triggers_response import ListTriggersResponse
    from .mapping import Mapping
    from .mark_down_with_context import MarkDownWithContext
    from .markdown_column import MarkdownColumn
    from .markdown_splitter_config import MarkdownSplitterConfig
    from .mcp_auth_type import McpAuthType
    from .me import Me
    from .me_update import MeUpdate
    from .mention import Mention
    from .mention_participant import MentionParticipant
    from .message import Message
    from .message_chunk import MessageChunk
    from .model_provider import ModelProvider
    from .multi_page_crawler_settings_input import MultiPageCrawlerSettingsInput
    from .multi_page_crawler_settings_input_scraper import MultiPageCrawlerSettingsInputScraper
    from .multi_page_crawler_settings_input_text_extractor import MultiPageCrawlerSettingsInputTextExtractor
    from .multi_page_crawler_settings_output import MultiPageCrawlerSettingsOutput
    from .multi_page_crawler_settings_output_scraper import MultiPageCrawlerSettingsOutputScraper
    from .multi_page_crawler_settings_output_text_extractor import MultiPageCrawlerSettingsOutputTextExtractor
    from .multi_select_column import MultiSelectColumn
    from .node_ui import NodeUi
    from .notification import Notification
    from .notification_action import NotificationAction
    from .notification_action_type import NotificationActionType
    from .notification_severity import NotificationSeverity
    from .notification_type import NotificationType
    from .notion_filter_by import NotionFilterBy
    from .notion_filter_options import NotionFilterOptions
    from .notion_o_auth_request import NotionOAuthRequest
    from .number_column import NumberColumn
    from .number_column_default import NumberColumnDefault
    from .number_column_max_value import NumberColumnMaxValue
    from .number_column_min_value import NumberColumnMinValue
    from .o_auth_auth_type import OAuthAuthType
    from .organization import Organization
    from .paragraph_splitter_config import ParagraphSplitterConfig
    from .participant import Participant
    from .participant_type import ParticipantType
    from .people_column import PeopleColumn
    from .placeholder_input import PlaceholderInput
    from .placeholder_input_type import PlaceholderInputType
    from .placeholder_output import PlaceholderOutput
    from .placeholder_output_type import PlaceholderOutputType
    from .plan import Plan
    from .plan_types import PlanTypes
    from .playwright import Playwright
    from .playwright_wait_for_load_state import PlaywrightWaitForLoadState
    from .position import Position
    from .prompt import Prompt
    from .prompt_role import PromptRole
    from .public_copilot_config import PublicCopilotConfig
    from .public_copilot_config_code_theme import PublicCopilotConfigCodeTheme
    from .public_copilot_config_fab_value import PublicCopilotConfigFabValue
    from .public_copilot_config_mode import PublicCopilotConfigMode
    from .public_copilot_response import PublicCopilotResponse
    from .pulse_feed_response import PulseFeedResponse
    from .pulse_hook import PulseHook
    from .pulse_hook_input import PulseHookInput
    from .pulse_target_config import PulseTargetConfig
    from .query_builder_request import QueryBuilderRequest
    from .query_builder_request_group_by_item import QueryBuilderRequestGroupByItem
    from .query_builder_request_sort_by import QueryBuilderRequestSortBy
    from .query_builder_request_sort_direction import QueryBuilderRequestSortDirection
    from .query_builder_request_tag_mode import QueryBuilderRequestTagMode
    from .query_request import QueryRequest
    from .query_sort import QuerySort
    from .readability import Readability
    from .recursive_splitter_config import RecursiveSplitterConfig
    from .relation_column import RelationColumn
    from .rename_request import RenameRequest
    from .rename_response import RenameResponse
    from .req_body import ReqBody
    from .request_body import RequestBody
    from .resource import Resource
    from .resource_resource_type import ResourceResourceType
    from .response_model_usage import ResponseModelUsage
    from .result import Result
    from .rotate_api_keys_request import RotateApiKeysRequest
    from .rule import Rule
    from .rules_input import RulesInput
    from .rules_output import RulesOutput
    from .run_log import RunLog
    from .run_log_pagination import RunLogPagination
    from .schedule import Schedule
    from .schema_response import SchemaResponse
    from .schemas_response import SchemasResponse
    from .scout_hook import ScoutHook
    from .scout_hook_config_http import ScoutHookConfigHttp
    from .scout_hook_event_discriminator import ScoutHookEventDiscriminator
    from .scout_hook_event_discriminator_type import ScoutHookEventDiscriminatorType
    from .scout_hook_event_trigger import ScoutHookEventTrigger
    from .scout_hook_response import ScoutHookResponse
    from .scout_hook_update import ScoutHookUpdate
    from .scout_hook_update_triggering_events_item import ScoutHookUpdateTriggeringEventsItem
    from .scout_hooks_response import ScoutHooksResponse
    from .scout_user import ScoutUser
    from .search_request import SearchRequest
    from .search_request_search_type import SearchRequestSearchType
    from .select_column import SelectColumn
    from .select_option_item import SelectOptionItem
    from .sentence_splitter_config import SentenceSplitterConfig
    from .service_info import ServiceInfo
    from .single_page_crawler_settings_input import SinglePageCrawlerSettingsInput
    from .single_page_crawler_settings_input_scraper import SinglePageCrawlerSettingsInputScraper
    from .single_page_crawler_settings_input_text_extractor import SinglePageCrawlerSettingsInputTextExtractor
    from .single_page_crawler_settings_output import SinglePageCrawlerSettingsOutput
    from .single_page_crawler_settings_output_scraper import SinglePageCrawlerSettingsOutputScraper
    from .single_page_crawler_settings_output_text_extractor import SinglePageCrawlerSettingsOutputTextExtractor
    from .sitemap_crawler_settings_input import SitemapCrawlerSettingsInput
    from .sitemap_crawler_settings_input_scraper import SitemapCrawlerSettingsInputScraper
    from .sitemap_crawler_settings_input_text_extractor import SitemapCrawlerSettingsInputTextExtractor
    from .sitemap_crawler_settings_output import SitemapCrawlerSettingsOutput
    from .sitemap_crawler_settings_output_scraper import SitemapCrawlerSettingsOutputScraper
    from .sitemap_crawler_settings_output_text_extractor import SitemapCrawlerSettingsOutputTextExtractor
    from .slack_event_response import SlackEventResponse
    from .slack_message_request import SlackMessageRequest
    from .slack_reaction_request import SlackReactionRequest
    from .slack_trigger_config_input import SlackTriggerConfigInput
    from .slack_trigger_config_input_action import SlackTriggerConfigInputAction
    from .slack_trigger_config_output import SlackTriggerConfigOutput
    from .slack_trigger_config_output_action import SlackTriggerConfigOutputAction
    from .slack_url_verification import SlackUrlVerification
    from .sort_direction import SortDirection
    from .source_archetype import SourceArchetype
    from .source_archetype_integration_version import SourceArchetypeIntegrationVersion
    from .source_sync import SourceSync
    from .source_sync_crawl_settings_input import SourceSyncCrawlSettingsInput
    from .source_sync_crawl_settings_input_mode import SourceSyncCrawlSettingsInputMode
    from .source_sync_crawl_settings_output import SourceSyncCrawlSettingsOutput
    from .source_sync_crawl_settings_output_mode import SourceSyncCrawlSettingsOutputMode
    from .source_sync_google_drive_settings import SourceSyncGoogleDriveSettings
    from .source_sync_notion_settings_input import SourceSyncNotionSettingsInput
    from .source_sync_notion_settings_output import SourceSyncNotionSettingsOutput
    from .source_sync_page_crawl_settings_input import SourceSyncPageCrawlSettingsInput
    from .source_sync_page_crawl_settings_input_mode import SourceSyncPageCrawlSettingsInputMode
    from .source_sync_page_crawl_settings_output import SourceSyncPageCrawlSettingsOutput
    from .source_sync_page_crawl_settings_output_mode import SourceSyncPageCrawlSettingsOutputMode
    from .source_sync_sitemap_settings_input import SourceSyncSitemapSettingsInput
    from .source_sync_sitemap_settings_input_mode import SourceSyncSitemapSettingsInputMode
    from .source_sync_sitemap_settings_output import SourceSyncSitemapSettingsOutput
    from .source_sync_sitemap_settings_output_mode import SourceSyncSitemapSettingsOutputMode
    from .source_sync_website_settings import SourceSyncWebsiteSettings
    from .source_sync_website_settings_splitter import SourceSyncWebsiteSettingsSplitter
    from .src_app_http_routes_billing_billing_hourly_data import SrcAppHttpRoutesBillingBillingHourlyData
    from .src_app_http_routes_billing_billing_hourly_response import SrcAppHttpRoutesBillingBillingHourlyResponse
    from .src_app_http_routes_billing_change_billing_plan_response import (
        SrcAppHttpRoutesBillingChangeBillingPlanResponse,
    )
    from .src_app_http_routes_billing_create_portal_session_data import SrcAppHttpRoutesBillingCreatePortalSessionData
    from .src_app_http_routes_billing_create_portal_session_response import (
        SrcAppHttpRoutesBillingCreatePortalSessionResponse,
    )
    from .src_app_http_routes_billing_free_plan_usage_data import SrcAppHttpRoutesBillingFreePlanUsageData
    from .src_app_http_routes_billing_free_plan_usage_response import SrcAppHttpRoutesBillingFreePlanUsageResponse
    from .src_app_http_routes_billing_get_billing_data import SrcAppHttpRoutesBillingGetBillingData
    from .src_app_http_routes_billing_get_billing_response import SrcAppHttpRoutesBillingGetBillingResponse
    from .src_app_http_routes_billing_get_info_get_info_response import SrcAppHttpRoutesBillingGetInfoGetInfoResponse
    from .src_app_http_routes_billing_get_invoices_data import SrcAppHttpRoutesBillingGetInvoicesData
    from .src_app_http_routes_billing_get_invoices_response import SrcAppHttpRoutesBillingGetInvoicesResponse
    from .src_app_http_routes_billing_get_notifications_response import SrcAppHttpRoutesBillingGetNotificationsResponse
    from .src_app_http_routes_billing_renew_plans_data import SrcAppHttpRoutesBillingRenewPlansData
    from .src_app_http_routes_billing_renew_plans_response import SrcAppHttpRoutesBillingRenewPlansResponse
    from .src_app_http_routes_collection_create_collection_response import (
        SrcAppHttpRoutesCollectionCreateCollectionResponse,
    )
    from .src_app_http_routes_collection_create_sync_response import SrcAppHttpRoutesCollectionCreateSyncResponse
    from .src_app_http_routes_collection_create_table_response import SrcAppHttpRoutesCollectionCreateTableResponse
    from .src_app_http_routes_collection_delete_collection_response import (
        SrcAppHttpRoutesCollectionDeleteCollectionResponse,
    )
    from .src_app_http_routes_collection_delete_documents_response import (
        SrcAppHttpRoutesCollectionDeleteDocumentsResponse,
    )
    from .src_app_http_routes_collection_delete_sync_response import SrcAppHttpRoutesCollectionDeleteSyncResponse
    from .src_app_http_routes_collection_delete_table_response import SrcAppHttpRoutesCollectionDeleteTableResponse
    from .src_app_http_routes_collection_get_collection_response import SrcAppHttpRoutesCollectionGetCollectionResponse
    from .src_app_http_routes_collection_get_collections_response import (
        SrcAppHttpRoutesCollectionGetCollectionsResponse,
    )
    from .src_app_http_routes_collection_get_document_response import SrcAppHttpRoutesCollectionGetDocumentResponse
    from .src_app_http_routes_collection_get_documents_response import SrcAppHttpRoutesCollectionGetDocumentsResponse
    from .src_app_http_routes_collection_get_sync_response import SrcAppHttpRoutesCollectionGetSyncResponse
    from .src_app_http_routes_collection_get_syncs_response import SrcAppHttpRoutesCollectionGetSyncsResponse
    from .src_app_http_routes_collection_get_table_response import SrcAppHttpRoutesCollectionGetTableResponse
    from .src_app_http_routes_collection_get_tables_response import SrcAppHttpRoutesCollectionGetTablesResponse
    from .src_app_http_routes_collection_list_collection_syncs_response_model import (
        SrcAppHttpRoutesCollectionListCollectionSyncsResponseModel,
    )
    from .src_app_http_routes_collection_list_source_archetypes_response_model import (
        SrcAppHttpRoutesCollectionListSourceArchetypesResponseModel,
    )
    from .src_app_http_routes_collection_parse_file_response import SrcAppHttpRoutesCollectionParseFileResponse
    from .src_app_http_routes_collection_sync_table_response import SrcAppHttpRoutesCollectionSyncTableResponse
    from .src_app_http_routes_collection_update_collection_response import (
        SrcAppHttpRoutesCollectionUpdateCollectionResponse,
    )
    from .src_app_http_routes_collection_update_document_response import (
        SrcAppHttpRoutesCollectionUpdateDocumentResponse,
    )
    from .src_app_http_routes_collection_update_sync_response import SrcAppHttpRoutesCollectionUpdateSyncResponse
    from .src_app_http_routes_collection_update_table_response import SrcAppHttpRoutesCollectionUpdateTableResponse
    from .src_app_http_routes_drive_create_drive_crawl_payload import SrcAppHttpRoutesDriveCreateDriveCrawlPayload
    from .src_app_http_routes_drive_create_drive_crawl_payload_source_sync_settings import (
        SrcAppHttpRoutesDriveCreateDriveCrawlPayloadSourceSyncSettings,
    )
    from .src_app_http_routes_drive_grant_access_payload import SrcAppHttpRoutesDriveGrantAccessPayload
    from .src_app_http_routes_drive_revoke_access_payload import SrcAppHttpRoutesDriveRevokeAccessPayload
    from .src_app_http_routes_inbox_handle_message_incoming_message import (
        SrcAppHttpRoutesInboxHandleMessageIncomingMessage,
    )
    from .src_app_http_routes_inbox_handle_message_incoming_message_content import (
        SrcAppHttpRoutesInboxHandleMessageIncomingMessageContent,
    )
    from .src_app_http_routes_inbox_handle_message_incoming_message_content_type import (
        SrcAppHttpRoutesInboxHandleMessageIncomingMessageContentType,
    )
    from .src_app_http_routes_inbox_handle_message_interaction_request import (
        SrcAppHttpRoutesInboxHandleMessageInteractionRequest,
    )
    from .src_app_http_routes_inbox_handle_message_interaction_request_participants_item import (
        SrcAppHttpRoutesInboxHandleMessageInteractionRequestParticipantsItem,
    )
    from .src_app_http_routes_integration_mcp_connect_mcp_payload import SrcAppHttpRoutesIntegrationMcpConnectMcpPayload
    from .src_app_http_routes_integration_mcp_exchange_mcp_auth_payload import (
        SrcAppHttpRoutesIntegrationMcpExchangeMcpAuthPayload,
    )
    from .src_app_http_routes_onboarding_handle_get_me_response import SrcAppHttpRoutesOnboardingHandleGetMeResponse
    from .src_app_http_routes_onboarding_handle_update_me_response import (
        SrcAppHttpRoutesOnboardingHandleUpdateMeResponse,
    )
    from .src_app_http_routes_root_get_info_response import SrcAppHttpRoutesRootGetInfoResponse
    from .src_app_http_routes_tags_create_tag_payload import SrcAppHttpRoutesTagsCreateTagPayload
    from .src_app_http_routes_tags_update_tag_payload import SrcAppHttpRoutesTagsUpdateTagPayload
    from .src_app_http_routes_trigger_create_trigger_response import SrcAppHttpRoutesTriggerCreateTriggerResponse
    from .src_app_http_routes_world_interact_incoming_message import SrcAppHttpRoutesWorldInteractIncomingMessage
    from .src_app_http_routes_world_interact_incoming_message_content import (
        SrcAppHttpRoutesWorldInteractIncomingMessageContent,
    )
    from .src_app_http_routes_world_interact_incoming_message_content_item import (
        SrcAppHttpRoutesWorldInteractIncomingMessageContentItem,
    )
    from .src_app_http_routes_world_interact_interaction_request import SrcAppHttpRoutesWorldInteractInteractionRequest
    from .src_handlers_create_copilot_response import SrcHandlersCreateCopilotResponse
    from .src_handlers_create_workflow_response import SrcHandlersCreateWorkflowResponse
    from .src_handlers_create_workflow_revision_response import SrcHandlersCreateWorkflowRevisionResponse
    from .src_handlers_delete_copilot_response import SrcHandlersDeleteCopilotResponse
    from .src_handlers_delete_workflow_response import SrcHandlersDeleteWorkflowResponse
    from .src_handlers_delete_workflow_revision_response import SrcHandlersDeleteWorkflowRevisionResponse
    from .src_handlers_get_copilot_response import SrcHandlersGetCopilotResponse
    from .src_handlers_get_workflow_environments_response import SrcHandlersGetWorkflowEnvironmentsResponse
    from .src_handlers_get_workflow_response import SrcHandlersGetWorkflowResponse
    from .src_handlers_list_copilots_response import SrcHandlersListCopilotsResponse
    from .src_handlers_list_workflow_revisions_response import SrcHandlersListWorkflowRevisionsResponse
    from .src_handlers_list_workflows_response import SrcHandlersListWorkflowsResponse
    from .src_handlers_promote_workflow_revision_response import SrcHandlersPromoteWorkflowRevisionResponse
    from .src_handlers_update_copilot_response import SrcHandlersUpdateCopilotResponse
    from .src_handlers_update_workflow_environment_response import SrcHandlersUpdateWorkflowEnvironmentResponse
    from .src_handlers_update_workflow_response import SrcHandlersUpdateWorkflowResponse
    from .src_handlers_update_workflow_revision_response import SrcHandlersUpdateWorkflowRevisionResponse
    from .store_response import StoreResponse
    from .stripe_provider import StripeProvider
    from .stripe_provider_meta import StripeProviderMeta
    from .subscription import Subscription
    from .sync import Sync
    from .sync_config_input import SyncConfigInput
    from .sync_config_input_source_settings import SyncConfigInputSourceSettings
    from .sync_config_output import SyncConfigOutput
    from .sync_config_output_source_settings import SyncConfigOutputSourceSettings
    from .table import Table
    from .table_config_output import TableConfigOutput
    from .table_config_output_schema_item import TableConfigOutputSchemaItem
    from .table_view_input import TableViewInput
    from .table_view_output import TableViewOutput
    from .table_view_settings_input import TableViewSettingsInput
    from .table_view_settings_input_row_height import TableViewSettingsInputRowHeight
    from .table_view_settings_output import TableViewSettingsOutput
    from .table_view_settings_output_row_height import TableViewSettingsOutputRowHeight
    from .tag import Tag
    from .tags_response import TagsResponse
    from .text_extractor import TextExtractor
    from .text_extractor_config import TextExtractorConfig
    from .text_long_column import TextLongColumn
    from .text_short_column import TextShortColumn
    from .tool import Tool
    from .tool_config_resource import ToolConfigResource
    from .tool_config_resource_type import ToolConfigResourceType
    from .tool_details import ToolDetails
    from .tools_data import ToolsData
    from .tools_response import ToolsResponse
    from .trafilatura_input import TrafilaturaInput
    from .trafilatura_input_trafilatura_type import TrafilaturaInputTrafilaturaType
    from .trafilatura_output import TrafilaturaOutput
    from .trafilatura_output_trafilatura_type import TrafilaturaOutputTrafilaturaType
    from .trigger import Trigger
    from .trigger_status import TriggerStatus
    from .trigger_trigger_config import TriggerTriggerConfig
    from .units import Units
    from .update_cron_auth_response import UpdateCronAuthResponse
    from .update_entity_request import UpdateEntityRequest
    from .update_questionnaire_files_request import UpdateQuestionnaireFilesRequest
    from .update_tag_response import UpdateTagResponse
    from .update_tags_request import UpdateTagsRequest
    from .update_trigger_response import UpdateTriggerResponse
    from .url_column import UrlColumn
    from .usage import Usage
    from .usage_types import UsageTypes
    from .user_identity import UserIdentity
    from .user_identity_details import UserIdentityDetails
    from .user_organization_config import UserOrganizationConfig
    from .validation_error import ValidationError
    from .validation_error_loc_item import ValidationErrorLocItem
    from .view_filter import ViewFilter
    from .view_list_response import ViewListResponse
    from .view_list_response_data_item import ViewListResponseDataItem
    from .view_query_input import ViewQueryInput
    from .view_query_output import ViewQueryOutput
    from .view_response import ViewResponse
    from .view_response_data import ViewResponseData
    from .view_state_response import ViewStateResponse
    from .view_visibility import ViewVisibility
    from .workflow import Workflow
    from .workflow_actor import WorkflowActor
    from .workflow_actor_type import WorkflowActorType
    from .workflow_config_input import WorkflowConfigInput
    from .workflow_config_output import WorkflowConfigOutput
    from .workflow_execute import WorkflowExecute
    from .workflow_hook import WorkflowHook
    from .workflow_hook_input import WorkflowHookInput
    from .workflow_note_input import WorkflowNoteInput
    from .workflow_note_output import WorkflowNoteOutput
    from .workflow_run import WorkflowRun
    from .workflow_run_completed import WorkflowRunCompleted
    from .workflow_run_completed_data import WorkflowRunCompletedData
    from .workflow_run_completed_environment import WorkflowRunCompletedEnvironment
    from .workflow_run_failed import WorkflowRunFailed
    from .workflow_run_failed_data import WorkflowRunFailedData
    from .workflow_run_failed_environment import WorkflowRunFailedEnvironment
    from .workflow_run_response import WorkflowRunResponse
    from .workflow_run_started import WorkflowRunStarted
    from .workflow_run_started_data import WorkflowRunStartedData
    from .workflow_run_started_environment import WorkflowRunStartedEnvironment
    from .workflow_run_state_value import WorkflowRunStateValue
    from .workflow_run_stop_reason import WorkflowRunStopReason
    from .workflow_run_stream_response import WorkflowRunStreamResponse
    from .workflow_target_config import WorkflowTargetConfig
_dynamic_imports: typing.Dict[str, str] = {
    "ActionType": ".action_type",
    "ActivitySchema": ".activity_schema",
    "Actor": ".actor",
    "ActorIdentity": ".actor_identity",
    "ActorIdentityId": ".actor_identity_id",
    "ActorIdentityType": ".actor_identity_type",
    "AgentHook": ".agent_hook",
    "AgentHookInput": ".agent_hook_input",
    "AgentRevision": ".agent_revision",
    "AgentRevisionModel": ".agent_revision_model",
    "AgentRevisionResponseStyle": ".agent_revision_response_style",
    "AgentRevisionToolConfigValue": ".agent_revision_tool_config_value",
    "AgentTargetConfig": ".agent_target_config",
    "AiAgent": ".ai_agent",
    "ApiKeyAuthType": ".api_key_auth_type",
    "ApiKeyIdentity": ".api_key_identity",
    "ApiKeyIdentityDetails": ".api_key_identity_details",
    "AutomationHook": ".automation_hook",
    "AutomationHookInput": ".automation_hook_input",
    "AutomationTargetConfig": ".automation_target_config",
    "BareInput": ".bare_input",
    "BareOutput": ".bare_output",
    "Baseline": ".baseline",
    "BatchCreateRequest": ".batch_create_request",
    "BatchGenerateRequest": ".batch_generate_request",
    "Billing": ".billing",
    "BillingCycle": ".billing_cycle",
    "BillingCycles": ".billing_cycles",
    "BillingLimits": ".billing_limits",
    "BillingUsage": ".billing_usage",
    "BlockConfigItemBoolean": ".block_config_item_boolean",
    "BlockConfigItemJson": ".block_config_item_json",
    "BlockConfigItemLlm": ".block_config_item_llm",
    "BlockConfigItemNumber": ".block_config_item_number",
    "BlockConfigItemNumberDefaultValue": ".block_config_item_number_default_value",
    "BlockConfigItemNumberMaximumValue": ".block_config_item_number_maximum_value",
    "BlockConfigItemNumberMinimumValue": ".block_config_item_number_minimum_value",
    "BlockConfigItemNumberValue": ".block_config_item_number_value",
    "BlockConfigItemSelect": ".block_config_item_select",
    "BlockConfigItemTextLong": ".block_config_item_text_long",
    "BlockConfigItemTextLongValue": ".block_config_item_text_long_value",
    "BlockConfigItemTextShort": ".block_config_item_text_short",
    "BlockInput": ".block_input",
    "BlockInputBlockConfigItem": ".block_input_block_config_item",
    "BlockOutput": ".block_output",
    "BlockOutputBlockConfigItem": ".block_output_block_config_item",
    "BlockRun": ".block_run",
    "BlockRunCompleted": ".block_run_completed",
    "BlockRunCompletedData": ".block_run_completed_data",
    "BlockRunCompletedEnvironment": ".block_run_completed_environment",
    "BlockRunFailed": ".block_run_failed",
    "BlockRunFailedData": ".block_run_failed_data",
    "BlockRunFailedEnvironment": ".block_run_failed_environment",
    "BlockRunStarted": ".block_run_started",
    "BlockRunStartedData": ".block_run_started_data",
    "BlockRunStartedEnvironment": ".block_run_started_environment",
    "BlockRunUsage": ".block_run_usage",
    "BlockStateUpdated": ".block_state_updated",
    "BlockStateUpdatedData": ".block_state_updated_data",
    "BlockStateUpdatedDataUpdateType": ".block_state_updated_data_update_type",
    "BlockStateUpdatedEnvironment": ".block_state_updated_environment",
    "BodyParseFileV2FilesParsePost": ".body_parse_file_v_2_files_parse_post",
    "BodyUploadFilesToDriveDriveFilesPost": ".body_upload_files_to_drive_drive_files_post",
    "BodyUploadPrivateFilesInboxSessionIdFilesPost": ".body_upload_private_files_inbox_session_id_files_post",
    "BodyUploadPulseFilesStreamPulseFilesStreamPost": ".body_upload_pulse_files_stream_pulse_files_stream_post",
    "BodyUpsertAgentAgentsPost": ".body_upsert_agent_agents_post",
    "CancelResponse": ".cancel_response",
    "CardDisplayField": ".card_display_field",
    "Channel": ".channel",
    "CheckBoxColumn": ".check_box_column",
    "Collection": ".collection",
    "CollectionConfig": ".collection_config",
    "CollectionDestination": ".collection_destination",
    "CollectionViewStateInput": ".collection_view_state_input",
    "CollectionViewStateInputViewsValue": ".collection_view_state_input_views_value",
    "CollectionViewStateOutput": ".collection_view_state_output",
    "CollectionViewStateOutputViewsValue": ".collection_view_state_output_views_value",
    "ColumnType": ".column_type",
    "ColumnTypeBase": ".column_type_base",
    "Condition": ".condition",
    "ConditionField": ".condition_field",
    "ConditionOperator": ".condition_operator",
    "ConnectIntegrationRequest": ".connect_integration_request",
    "ConnectIntegrationRequestAuthType": ".connect_integration_request_auth_type",
    "Copilot": ".copilot",
    "CopilotConfig": ".copilot_config",
    "CopilotConfigCodeTheme": ".copilot_config_code_theme",
    "CopilotConfigFabValue": ".copilot_config_fab_value",
    "CopilotConfigMode": ".copilot_config_mode",
    "CreateEntityRequest": ".create_entity_request",
    "CreateIntegrationsResponse": ".create_integrations_response",
    "CreatePulseRequest": ".create_pulse_request",
    "CreatePulseResponse": ".create_pulse_response",
    "CreateTagResponse": ".create_tag_response",
    "CronTriggerConfig": ".cron_trigger_config",
    "CronTriggerConfigAction": ".cron_trigger_config_action",
    "Custom": ".custom",
    "DailyUsage": ".daily_usage",
    "DataType": ".data_type",
    "DateTimeColumn": ".date_time_column",
    "DefaultInput": ".default_input",
    "DefaultOutput": ".default_output",
    "DeleteHookResponse": ".delete_hook_response",
    "DeleteResponse": ".delete_response",
    "DeleteTriggerResponse": ".delete_trigger_response",
    "DeleteViewResponse": ".delete_view_response",
    "Dependency": ".dependency",
    "DeterminedBillingLimits": ".determined_billing_limits",
    "Dimensions": ".dimensions",
    "Document": ".document",
    "DocumentCreatedBy": ".document_created_by",
    "DocumentDataValue": ".document_data_value",
    "DocumentLastUpdatedBy": ".document_last_updated_by",
    "DocumentResponse": ".document_response",
    "EdgeUi": ".edge_ui",
    "EntityQueryRequest": ".entity_query_request",
    "EntityResponse": ".entity_response",
    "EntitySearchRequest": ".entity_search_request",
    "EntitySearchRequestMode": ".entity_search_request_mode",
    "EntitySearchRequestReturnFormat": ".entity_search_request_return_format",
    "Environment": ".environment",
    "EnvironmentConfig": ".environment_config",
    "EnvironmentDeploymentConfig": ".environment_deployment_config",
    "EnvironmentDeploymentConfigRevisionLookup": ".environment_deployment_config_revision_lookup",
    "EnvironmentDeploymentDocument": ".environment_deployment_document",
    "EventVersion": ".event_version",
    "ExecuteToolRequest": ".execute_tool_request",
    "ExecuteToolResponse": ".execute_tool_response",
    "ExecuteTriggerResponse": ".execute_trigger_response",
    "Favor": ".favor",
    "FavoriteItem": ".favorite_item",
    "FavoriteRef": ".favorite_ref",
    "FieldMapping": ".field_mapping",
    "File": ".file",
    "FilesAttribute": ".files_attribute",
    "FilesResponse": ".files_response",
    "FilterOperator": ".filter_operator",
    "FilterType": ".filter_type",
    "Flags": ".flags",
    "FluentQueryRequest": ".fluent_query_request",
    "FluentQueryRequestWithItem": ".fluent_query_request_with_item",
    "FriendlyInvoice": ".friendly_invoice",
    "FriendlyPaymentMethods": ".friendly_payment_methods",
    "GenerateAiSuggestionRequest": ".generate_ai_suggestion_request",
    "HookUpdate": ".hook_update",
    "HooksListResponse": ".hooks_list_response",
    "Html2Text": ".html_2_text",
    "Http": ".http",
    "HttpValidationError": ".http_validation_error",
    "Identity": ".identity",
    "IdentityDetails": ".identity_details",
    "IdentityTypes": ".identity_types",
    "Integration": ".integration",
    "IntegrationAuthType": ".integration_auth_type",
    "IntegrationConnection": ".integration_connection",
    "IntegrationConnectionAuthType": ".integration_connection_auth_type",
    "IntegrationConnectionIntegrationType": ".integration_connection_integration_type",
    "IntegrationWithConnections": ".integration_with_connections",
    "IntegrationWithConnectionsId": ".integration_with_connections_id",
    "Interval": ".interval",
    "IntervalTypes": ".interval_types",
    "Invoice": ".invoice",
    "InvoiceMeta": ".invoice_meta",
    "InvoiceStatus": ".invoice_status",
    "JsonColumn": ".json_column",
    "KanbanViewInput": ".kanban_view_input",
    "KanbanViewOutput": ".kanban_view_output",
    "KanbanViewSettingsInput": ".kanban_view_settings_input",
    "KanbanViewSettingsOutput": ".kanban_view_settings_output",
    "LegacyIdentity": ".legacy_identity",
    "LegacyIdentityDetails": ".legacy_identity_details",
    "LineItem": ".line_item",
    "ListTagsResponse": ".list_tags_response",
    "ListToolsResponse": ".list_tools_response",
    "ListTriggersResponse": ".list_triggers_response",
    "Mapping": ".mapping",
    "MarkDownWithContext": ".mark_down_with_context",
    "MarkdownColumn": ".markdown_column",
    "MarkdownSplitterConfig": ".markdown_splitter_config",
    "McpAuthType": ".mcp_auth_type",
    "Me": ".me",
    "MeUpdate": ".me_update",
    "Mention": ".mention",
    "MentionParticipant": ".mention_participant",
    "Message": ".message",
    "MessageChunk": ".message_chunk",
    "ModelProvider": ".model_provider",
    "MultiPageCrawlerSettingsInput": ".multi_page_crawler_settings_input",
    "MultiPageCrawlerSettingsInputScraper": ".multi_page_crawler_settings_input_scraper",
    "MultiPageCrawlerSettingsInputTextExtractor": ".multi_page_crawler_settings_input_text_extractor",
    "MultiPageCrawlerSettingsOutput": ".multi_page_crawler_settings_output",
    "MultiPageCrawlerSettingsOutputScraper": ".multi_page_crawler_settings_output_scraper",
    "MultiPageCrawlerSettingsOutputTextExtractor": ".multi_page_crawler_settings_output_text_extractor",
    "MultiSelectColumn": ".multi_select_column",
    "NodeUi": ".node_ui",
    "Notification": ".notification",
    "NotificationAction": ".notification_action",
    "NotificationActionType": ".notification_action_type",
    "NotificationSeverity": ".notification_severity",
    "NotificationType": ".notification_type",
    "NotionFilterBy": ".notion_filter_by",
    "NotionFilterOptions": ".notion_filter_options",
    "NotionOAuthRequest": ".notion_o_auth_request",
    "NumberColumn": ".number_column",
    "NumberColumnDefault": ".number_column_default",
    "NumberColumnMaxValue": ".number_column_max_value",
    "NumberColumnMinValue": ".number_column_min_value",
    "OAuthAuthType": ".o_auth_auth_type",
    "Organization": ".organization",
    "ParagraphSplitterConfig": ".paragraph_splitter_config",
    "Participant": ".participant",
    "ParticipantType": ".participant_type",
    "PeopleColumn": ".people_column",
    "PlaceholderInput": ".placeholder_input",
    "PlaceholderInputType": ".placeholder_input_type",
    "PlaceholderOutput": ".placeholder_output",
    "PlaceholderOutputType": ".placeholder_output_type",
    "Plan": ".plan",
    "PlanTypes": ".plan_types",
    "Playwright": ".playwright",
    "PlaywrightWaitForLoadState": ".playwright_wait_for_load_state",
    "Position": ".position",
    "Prompt": ".prompt",
    "PromptRole": ".prompt_role",
    "PublicCopilotConfig": ".public_copilot_config",
    "PublicCopilotConfigCodeTheme": ".public_copilot_config_code_theme",
    "PublicCopilotConfigFabValue": ".public_copilot_config_fab_value",
    "PublicCopilotConfigMode": ".public_copilot_config_mode",
    "PublicCopilotResponse": ".public_copilot_response",
    "PulseFeedResponse": ".pulse_feed_response",
    "PulseHook": ".pulse_hook",
    "PulseHookInput": ".pulse_hook_input",
    "PulseTargetConfig": ".pulse_target_config",
    "QueryBuilderRequest": ".query_builder_request",
    "QueryBuilderRequestGroupByItem": ".query_builder_request_group_by_item",
    "QueryBuilderRequestSortBy": ".query_builder_request_sort_by",
    "QueryBuilderRequestSortDirection": ".query_builder_request_sort_direction",
    "QueryBuilderRequestTagMode": ".query_builder_request_tag_mode",
    "QueryRequest": ".query_request",
    "QuerySort": ".query_sort",
    "Readability": ".readability",
    "RecursiveSplitterConfig": ".recursive_splitter_config",
    "RelationColumn": ".relation_column",
    "RenameRequest": ".rename_request",
    "RenameResponse": ".rename_response",
    "ReqBody": ".req_body",
    "RequestBody": ".request_body",
    "Resource": ".resource",
    "ResourceResourceType": ".resource_resource_type",
    "ResponseModelUsage": ".response_model_usage",
    "Result": ".result",
    "RotateApiKeysRequest": ".rotate_api_keys_request",
    "Rule": ".rule",
    "RulesInput": ".rules_input",
    "RulesOutput": ".rules_output",
    "RunLog": ".run_log",
    "RunLogPagination": ".run_log_pagination",
    "Schedule": ".schedule",
    "SchemaResponse": ".schema_response",
    "SchemasResponse": ".schemas_response",
    "ScoutHook": ".scout_hook",
    "ScoutHookConfigHttp": ".scout_hook_config_http",
    "ScoutHookEventDiscriminator": ".scout_hook_event_discriminator",
    "ScoutHookEventDiscriminatorType": ".scout_hook_event_discriminator_type",
    "ScoutHookEventTrigger": ".scout_hook_event_trigger",
    "ScoutHookResponse": ".scout_hook_response",
    "ScoutHookUpdate": ".scout_hook_update",
    "ScoutHookUpdateTriggeringEventsItem": ".scout_hook_update_triggering_events_item",
    "ScoutHooksResponse": ".scout_hooks_response",
    "ScoutUser": ".scout_user",
    "SearchRequest": ".search_request",
    "SearchRequestSearchType": ".search_request_search_type",
    "SelectColumn": ".select_column",
    "SelectOptionItem": ".select_option_item",
    "SentenceSplitterConfig": ".sentence_splitter_config",
    "ServiceInfo": ".service_info",
    "SinglePageCrawlerSettingsInput": ".single_page_crawler_settings_input",
    "SinglePageCrawlerSettingsInputScraper": ".single_page_crawler_settings_input_scraper",
    "SinglePageCrawlerSettingsInputTextExtractor": ".single_page_crawler_settings_input_text_extractor",
    "SinglePageCrawlerSettingsOutput": ".single_page_crawler_settings_output",
    "SinglePageCrawlerSettingsOutputScraper": ".single_page_crawler_settings_output_scraper",
    "SinglePageCrawlerSettingsOutputTextExtractor": ".single_page_crawler_settings_output_text_extractor",
    "SitemapCrawlerSettingsInput": ".sitemap_crawler_settings_input",
    "SitemapCrawlerSettingsInputScraper": ".sitemap_crawler_settings_input_scraper",
    "SitemapCrawlerSettingsInputTextExtractor": ".sitemap_crawler_settings_input_text_extractor",
    "SitemapCrawlerSettingsOutput": ".sitemap_crawler_settings_output",
    "SitemapCrawlerSettingsOutputScraper": ".sitemap_crawler_settings_output_scraper",
    "SitemapCrawlerSettingsOutputTextExtractor": ".sitemap_crawler_settings_output_text_extractor",
    "SlackEventResponse": ".slack_event_response",
    "SlackMessageRequest": ".slack_message_request",
    "SlackReactionRequest": ".slack_reaction_request",
    "SlackTriggerConfigInput": ".slack_trigger_config_input",
    "SlackTriggerConfigInputAction": ".slack_trigger_config_input_action",
    "SlackTriggerConfigOutput": ".slack_trigger_config_output",
    "SlackTriggerConfigOutputAction": ".slack_trigger_config_output_action",
    "SlackUrlVerification": ".slack_url_verification",
    "SortDirection": ".sort_direction",
    "SourceArchetype": ".source_archetype",
    "SourceArchetypeIntegrationVersion": ".source_archetype_integration_version",
    "SourceSync": ".source_sync",
    "SourceSyncCrawlSettingsInput": ".source_sync_crawl_settings_input",
    "SourceSyncCrawlSettingsInputMode": ".source_sync_crawl_settings_input_mode",
    "SourceSyncCrawlSettingsOutput": ".source_sync_crawl_settings_output",
    "SourceSyncCrawlSettingsOutputMode": ".source_sync_crawl_settings_output_mode",
    "SourceSyncGoogleDriveSettings": ".source_sync_google_drive_settings",
    "SourceSyncNotionSettingsInput": ".source_sync_notion_settings_input",
    "SourceSyncNotionSettingsOutput": ".source_sync_notion_settings_output",
    "SourceSyncPageCrawlSettingsInput": ".source_sync_page_crawl_settings_input",
    "SourceSyncPageCrawlSettingsInputMode": ".source_sync_page_crawl_settings_input_mode",
    "SourceSyncPageCrawlSettingsOutput": ".source_sync_page_crawl_settings_output",
    "SourceSyncPageCrawlSettingsOutputMode": ".source_sync_page_crawl_settings_output_mode",
    "SourceSyncSitemapSettingsInput": ".source_sync_sitemap_settings_input",
    "SourceSyncSitemapSettingsInputMode": ".source_sync_sitemap_settings_input_mode",
    "SourceSyncSitemapSettingsOutput": ".source_sync_sitemap_settings_output",
    "SourceSyncSitemapSettingsOutputMode": ".source_sync_sitemap_settings_output_mode",
    "SourceSyncWebsiteSettings": ".source_sync_website_settings",
    "SourceSyncWebsiteSettingsSplitter": ".source_sync_website_settings_splitter",
    "SrcAppHttpRoutesBillingBillingHourlyData": ".src_app_http_routes_billing_billing_hourly_data",
    "SrcAppHttpRoutesBillingBillingHourlyResponse": ".src_app_http_routes_billing_billing_hourly_response",
    "SrcAppHttpRoutesBillingChangeBillingPlanResponse": ".src_app_http_routes_billing_change_billing_plan_response",
    "SrcAppHttpRoutesBillingCreatePortalSessionData": ".src_app_http_routes_billing_create_portal_session_data",
    "SrcAppHttpRoutesBillingCreatePortalSessionResponse": ".src_app_http_routes_billing_create_portal_session_response",
    "SrcAppHttpRoutesBillingFreePlanUsageData": ".src_app_http_routes_billing_free_plan_usage_data",
    "SrcAppHttpRoutesBillingFreePlanUsageResponse": ".src_app_http_routes_billing_free_plan_usage_response",
    "SrcAppHttpRoutesBillingGetBillingData": ".src_app_http_routes_billing_get_billing_data",
    "SrcAppHttpRoutesBillingGetBillingResponse": ".src_app_http_routes_billing_get_billing_response",
    "SrcAppHttpRoutesBillingGetInfoGetInfoResponse": ".src_app_http_routes_billing_get_info_get_info_response",
    "SrcAppHttpRoutesBillingGetInvoicesData": ".src_app_http_routes_billing_get_invoices_data",
    "SrcAppHttpRoutesBillingGetInvoicesResponse": ".src_app_http_routes_billing_get_invoices_response",
    "SrcAppHttpRoutesBillingGetNotificationsResponse": ".src_app_http_routes_billing_get_notifications_response",
    "SrcAppHttpRoutesBillingRenewPlansData": ".src_app_http_routes_billing_renew_plans_data",
    "SrcAppHttpRoutesBillingRenewPlansResponse": ".src_app_http_routes_billing_renew_plans_response",
    "SrcAppHttpRoutesCollectionCreateCollectionResponse": ".src_app_http_routes_collection_create_collection_response",
    "SrcAppHttpRoutesCollectionCreateSyncResponse": ".src_app_http_routes_collection_create_sync_response",
    "SrcAppHttpRoutesCollectionCreateTableResponse": ".src_app_http_routes_collection_create_table_response",
    "SrcAppHttpRoutesCollectionDeleteCollectionResponse": ".src_app_http_routes_collection_delete_collection_response",
    "SrcAppHttpRoutesCollectionDeleteDocumentsResponse": ".src_app_http_routes_collection_delete_documents_response",
    "SrcAppHttpRoutesCollectionDeleteSyncResponse": ".src_app_http_routes_collection_delete_sync_response",
    "SrcAppHttpRoutesCollectionDeleteTableResponse": ".src_app_http_routes_collection_delete_table_response",
    "SrcAppHttpRoutesCollectionGetCollectionResponse": ".src_app_http_routes_collection_get_collection_response",
    "SrcAppHttpRoutesCollectionGetCollectionsResponse": ".src_app_http_routes_collection_get_collections_response",
    "SrcAppHttpRoutesCollectionGetDocumentResponse": ".src_app_http_routes_collection_get_document_response",
    "SrcAppHttpRoutesCollectionGetDocumentsResponse": ".src_app_http_routes_collection_get_documents_response",
    "SrcAppHttpRoutesCollectionGetSyncResponse": ".src_app_http_routes_collection_get_sync_response",
    "SrcAppHttpRoutesCollectionGetSyncsResponse": ".src_app_http_routes_collection_get_syncs_response",
    "SrcAppHttpRoutesCollectionGetTableResponse": ".src_app_http_routes_collection_get_table_response",
    "SrcAppHttpRoutesCollectionGetTablesResponse": ".src_app_http_routes_collection_get_tables_response",
    "SrcAppHttpRoutesCollectionListCollectionSyncsResponseModel": ".src_app_http_routes_collection_list_collection_syncs_response_model",
    "SrcAppHttpRoutesCollectionListSourceArchetypesResponseModel": ".src_app_http_routes_collection_list_source_archetypes_response_model",
    "SrcAppHttpRoutesCollectionParseFileResponse": ".src_app_http_routes_collection_parse_file_response",
    "SrcAppHttpRoutesCollectionSyncTableResponse": ".src_app_http_routes_collection_sync_table_response",
    "SrcAppHttpRoutesCollectionUpdateCollectionResponse": ".src_app_http_routes_collection_update_collection_response",
    "SrcAppHttpRoutesCollectionUpdateDocumentResponse": ".src_app_http_routes_collection_update_document_response",
    "SrcAppHttpRoutesCollectionUpdateSyncResponse": ".src_app_http_routes_collection_update_sync_response",
    "SrcAppHttpRoutesCollectionUpdateTableResponse": ".src_app_http_routes_collection_update_table_response",
    "SrcAppHttpRoutesDriveCreateDriveCrawlPayload": ".src_app_http_routes_drive_create_drive_crawl_payload",
    "SrcAppHttpRoutesDriveCreateDriveCrawlPayloadSourceSyncSettings": ".src_app_http_routes_drive_create_drive_crawl_payload_source_sync_settings",
    "SrcAppHttpRoutesDriveGrantAccessPayload": ".src_app_http_routes_drive_grant_access_payload",
    "SrcAppHttpRoutesDriveRevokeAccessPayload": ".src_app_http_routes_drive_revoke_access_payload",
    "SrcAppHttpRoutesInboxHandleMessageIncomingMessage": ".src_app_http_routes_inbox_handle_message_incoming_message",
    "SrcAppHttpRoutesInboxHandleMessageIncomingMessageContent": ".src_app_http_routes_inbox_handle_message_incoming_message_content",
    "SrcAppHttpRoutesInboxHandleMessageIncomingMessageContentType": ".src_app_http_routes_inbox_handle_message_incoming_message_content_type",
    "SrcAppHttpRoutesInboxHandleMessageInteractionRequest": ".src_app_http_routes_inbox_handle_message_interaction_request",
    "SrcAppHttpRoutesInboxHandleMessageInteractionRequestParticipantsItem": ".src_app_http_routes_inbox_handle_message_interaction_request_participants_item",
    "SrcAppHttpRoutesIntegrationMcpConnectMcpPayload": ".src_app_http_routes_integration_mcp_connect_mcp_payload",
    "SrcAppHttpRoutesIntegrationMcpExchangeMcpAuthPayload": ".src_app_http_routes_integration_mcp_exchange_mcp_auth_payload",
    "SrcAppHttpRoutesOnboardingHandleGetMeResponse": ".src_app_http_routes_onboarding_handle_get_me_response",
    "SrcAppHttpRoutesOnboardingHandleUpdateMeResponse": ".src_app_http_routes_onboarding_handle_update_me_response",
    "SrcAppHttpRoutesRootGetInfoResponse": ".src_app_http_routes_root_get_info_response",
    "SrcAppHttpRoutesTagsCreateTagPayload": ".src_app_http_routes_tags_create_tag_payload",
    "SrcAppHttpRoutesTagsUpdateTagPayload": ".src_app_http_routes_tags_update_tag_payload",
    "SrcAppHttpRoutesTriggerCreateTriggerResponse": ".src_app_http_routes_trigger_create_trigger_response",
    "SrcAppHttpRoutesWorldInteractIncomingMessage": ".src_app_http_routes_world_interact_incoming_message",
    "SrcAppHttpRoutesWorldInteractIncomingMessageContent": ".src_app_http_routes_world_interact_incoming_message_content",
    "SrcAppHttpRoutesWorldInteractIncomingMessageContentItem": ".src_app_http_routes_world_interact_incoming_message_content_item",
    "SrcAppHttpRoutesWorldInteractInteractionRequest": ".src_app_http_routes_world_interact_interaction_request",
    "SrcHandlersCreateCopilotResponse": ".src_handlers_create_copilot_response",
    "SrcHandlersCreateWorkflowResponse": ".src_handlers_create_workflow_response",
    "SrcHandlersCreateWorkflowRevisionResponse": ".src_handlers_create_workflow_revision_response",
    "SrcHandlersDeleteCopilotResponse": ".src_handlers_delete_copilot_response",
    "SrcHandlersDeleteWorkflowResponse": ".src_handlers_delete_workflow_response",
    "SrcHandlersDeleteWorkflowRevisionResponse": ".src_handlers_delete_workflow_revision_response",
    "SrcHandlersGetCopilotResponse": ".src_handlers_get_copilot_response",
    "SrcHandlersGetWorkflowEnvironmentsResponse": ".src_handlers_get_workflow_environments_response",
    "SrcHandlersGetWorkflowResponse": ".src_handlers_get_workflow_response",
    "SrcHandlersListCopilotsResponse": ".src_handlers_list_copilots_response",
    "SrcHandlersListWorkflowRevisionsResponse": ".src_handlers_list_workflow_revisions_response",
    "SrcHandlersListWorkflowsResponse": ".src_handlers_list_workflows_response",
    "SrcHandlersPromoteWorkflowRevisionResponse": ".src_handlers_promote_workflow_revision_response",
    "SrcHandlersUpdateCopilotResponse": ".src_handlers_update_copilot_response",
    "SrcHandlersUpdateWorkflowEnvironmentResponse": ".src_handlers_update_workflow_environment_response",
    "SrcHandlersUpdateWorkflowResponse": ".src_handlers_update_workflow_response",
    "SrcHandlersUpdateWorkflowRevisionResponse": ".src_handlers_update_workflow_revision_response",
    "StoreResponse": ".store_response",
    "StripeProvider": ".stripe_provider",
    "StripeProviderMeta": ".stripe_provider_meta",
    "Subscription": ".subscription",
    "Sync": ".sync",
    "SyncConfigInput": ".sync_config_input",
    "SyncConfigInputSourceSettings": ".sync_config_input_source_settings",
    "SyncConfigOutput": ".sync_config_output",
    "SyncConfigOutputSourceSettings": ".sync_config_output_source_settings",
    "Table": ".table",
    "TableConfigOutput": ".table_config_output",
    "TableConfigOutputSchemaItem": ".table_config_output_schema_item",
    "TableViewInput": ".table_view_input",
    "TableViewOutput": ".table_view_output",
    "TableViewSettingsInput": ".table_view_settings_input",
    "TableViewSettingsInputRowHeight": ".table_view_settings_input_row_height",
    "TableViewSettingsOutput": ".table_view_settings_output",
    "TableViewSettingsOutputRowHeight": ".table_view_settings_output_row_height",
    "Tag": ".tag",
    "TagsResponse": ".tags_response",
    "TextExtractor": ".text_extractor",
    "TextExtractorConfig": ".text_extractor_config",
    "TextLongColumn": ".text_long_column",
    "TextShortColumn": ".text_short_column",
    "Tool": ".tool",
    "ToolConfigResource": ".tool_config_resource",
    "ToolConfigResourceType": ".tool_config_resource_type",
    "ToolDetails": ".tool_details",
    "ToolsData": ".tools_data",
    "ToolsResponse": ".tools_response",
    "TrafilaturaInput": ".trafilatura_input",
    "TrafilaturaInputTrafilaturaType": ".trafilatura_input_trafilatura_type",
    "TrafilaturaOutput": ".trafilatura_output",
    "TrafilaturaOutputTrafilaturaType": ".trafilatura_output_trafilatura_type",
    "Trigger": ".trigger",
    "TriggerStatus": ".trigger_status",
    "TriggerTriggerConfig": ".trigger_trigger_config",
    "TypescriptAutomationConfig": ".typescript_automation_config",
    "Units": ".units",
    "UpdateCronAuthResponse": ".update_cron_auth_response",
    "UpdateEntityRequest": ".update_entity_request",
    "UpdateQuestionnaireFilesRequest": ".update_questionnaire_files_request",
    "UpdateTagResponse": ".update_tag_response",
    "UpdateTagsRequest": ".update_tags_request",
    "UpdateTriggerResponse": ".update_trigger_response",
    "UrlColumn": ".url_column",
    "Usage": ".usage",
    "UsageTypes": ".usage_types",
    "UserIdentity": ".user_identity",
    "UserIdentityDetails": ".user_identity_details",
    "UserOrganizationConfig": ".user_organization_config",
    "ValidationError": ".validation_error",
    "ValidationErrorLocItem": ".validation_error_loc_item",
    "ViewFilter": ".view_filter",
    "ViewListResponse": ".view_list_response",
    "ViewListResponseDataItem": ".view_list_response_data_item",
    "ViewQueryInput": ".view_query_input",
    "ViewQueryOutput": ".view_query_output",
    "ViewResponse": ".view_response",
    "ViewResponseData": ".view_response_data",
    "ViewStateResponse": ".view_state_response",
    "ViewVisibility": ".view_visibility",
    "Workflow": ".workflow",
    "WorkflowActor": ".workflow_actor",
    "WorkflowActorType": ".workflow_actor_type",
    "WorkflowConfigInput": ".workflow_config_input",
    "WorkflowConfigOutput": ".workflow_config_output",
    "WorkflowExecute": ".workflow_execute",
    "WorkflowHook": ".workflow_hook",
    "WorkflowHookInput": ".workflow_hook_input",
    "WorkflowNoteInput": ".workflow_note_input",
    "WorkflowNoteOutput": ".workflow_note_output",
    "WorkflowRun": ".workflow_run",
    "WorkflowRunCompleted": ".workflow_run_completed",
    "WorkflowRunCompletedData": ".workflow_run_completed_data",
    "WorkflowRunCompletedEnvironment": ".workflow_run_completed_environment",
    "WorkflowRunFailed": ".workflow_run_failed",
    "WorkflowRunFailedData": ".workflow_run_failed_data",
    "WorkflowRunFailedEnvironment": ".workflow_run_failed_environment",
    "WorkflowRunResponse": ".workflow_run_response",
    "WorkflowRunStarted": ".workflow_run_started",
    "WorkflowRunStartedData": ".workflow_run_started_data",
    "WorkflowRunStartedEnvironment": ".workflow_run_started_environment",
    "WorkflowRunStateValue": ".workflow_run_state_value",
    "WorkflowRunStopReason": ".workflow_run_stop_reason",
    "WorkflowRunStreamResponse": ".workflow_run_stream_response",
    "WorkflowTargetConfig": ".workflow_target_config",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "ActionType",
    "ActivitySchema",
    "Actor",
    "ActorIdentity",
    "ActorIdentityId",
    "ActorIdentityType",
    "AgentHook",
    "AgentHookInput",
    "AgentRevision",
    "AgentRevisionModel",
    "AgentRevisionResponseStyle",
    "AgentRevisionToolConfigValue",
    "AgentTargetConfig",
    "AiAgent",
    "ApiKeyAuthType",
    "ApiKeyIdentity",
    "ApiKeyIdentityDetails",
    "AutomationHook",
    "AutomationHookInput",
    "AutomationTargetConfig",
    "BareInput",
    "BareOutput",
    "Baseline",
    "BatchCreateRequest",
    "BatchGenerateRequest",
    "Billing",
    "BillingCycle",
    "BillingCycles",
    "BillingLimits",
    "BillingUsage",
    "BlockConfigItemBoolean",
    "BlockConfigItemJson",
    "BlockConfigItemLlm",
    "BlockConfigItemNumber",
    "BlockConfigItemNumberDefaultValue",
    "BlockConfigItemNumberMaximumValue",
    "BlockConfigItemNumberMinimumValue",
    "BlockConfigItemNumberValue",
    "BlockConfigItemSelect",
    "BlockConfigItemTextLong",
    "BlockConfigItemTextLongValue",
    "BlockConfigItemTextShort",
    "BlockInput",
    "BlockInputBlockConfigItem",
    "BlockOutput",
    "BlockOutputBlockConfigItem",
    "BlockRun",
    "BlockRunCompleted",
    "BlockRunCompletedData",
    "BlockRunCompletedEnvironment",
    "BlockRunFailed",
    "BlockRunFailedData",
    "BlockRunFailedEnvironment",
    "BlockRunStarted",
    "BlockRunStartedData",
    "BlockRunStartedEnvironment",
    "BlockRunUsage",
    "BlockStateUpdated",
    "BlockStateUpdatedData",
    "BlockStateUpdatedDataUpdateType",
    "BlockStateUpdatedEnvironment",
    "BodyParseFileV2FilesParsePost",
    "BodyUploadFilesToDriveDriveFilesPost",
    "BodyUploadPrivateFilesInboxSessionIdFilesPost",
    "BodyUploadPulseFilesStreamPulseFilesStreamPost",
    "BodyUpsertAgentAgentsPost",
    "CancelResponse",
    "CardDisplayField",
    "Channel",
    "CheckBoxColumn",
    "Collection",
    "CollectionConfig",
    "CollectionDestination",
    "CollectionViewStateInput",
    "CollectionViewStateInputViewsValue",
    "CollectionViewStateOutput",
    "CollectionViewStateOutputViewsValue",
    "ColumnType",
    "ColumnTypeBase",
    "Condition",
    "ConditionField",
    "ConditionOperator",
    "ConnectIntegrationRequest",
    "ConnectIntegrationRequestAuthType",
    "Copilot",
    "CopilotConfig",
    "CopilotConfigCodeTheme",
    "CopilotConfigFabValue",
    "CopilotConfigMode",
    "CreateEntityRequest",
    "CreateIntegrationsResponse",
    "CreatePulseRequest",
    "CreatePulseResponse",
    "CreateTagResponse",
    "CronTriggerConfig",
    "CronTriggerConfigAction",
    "Custom",
    "DailyUsage",
    "DataType",
    "DateTimeColumn",
    "DefaultInput",
    "DefaultOutput",
    "DeleteHookResponse",
    "DeleteResponse",
    "DeleteTriggerResponse",
    "DeleteViewResponse",
    "Dependency",
    "DeterminedBillingLimits",
    "Dimensions",
    "Document",
    "DocumentCreatedBy",
    "DocumentDataValue",
    "DocumentLastUpdatedBy",
    "DocumentResponse",
    "EdgeUi",
    "EntityQueryRequest",
    "EntityResponse",
    "EntitySearchRequest",
    "EntitySearchRequestMode",
    "EntitySearchRequestReturnFormat",
    "Environment",
    "EnvironmentConfig",
    "EnvironmentDeploymentConfig",
    "EnvironmentDeploymentConfigRevisionLookup",
    "EnvironmentDeploymentDocument",
    "EventVersion",
    "ExecuteToolRequest",
    "ExecuteToolResponse",
    "ExecuteTriggerResponse",
    "Favor",
    "FavoriteItem",
    "FavoriteRef",
    "FieldMapping",
    "File",
    "FilesAttribute",
    "FilesResponse",
    "FilterOperator",
    "FilterType",
    "Flags",
    "FluentQueryRequest",
    "FluentQueryRequestWithItem",
    "FriendlyInvoice",
    "FriendlyPaymentMethods",
    "GenerateAiSuggestionRequest",
    "HookUpdate",
    "HooksListResponse",
    "Html2Text",
    "Http",
    "HttpValidationError",
    "Identity",
    "IdentityDetails",
    "IdentityTypes",
    "Integration",
    "IntegrationAuthType",
    "IntegrationConnection",
    "IntegrationConnectionAuthType",
    "IntegrationConnectionIntegrationType",
    "IntegrationWithConnections",
    "IntegrationWithConnectionsId",
    "Interval",
    "IntervalTypes",
    "Invoice",
    "InvoiceMeta",
    "InvoiceStatus",
    "JsonColumn",
    "KanbanViewInput",
    "KanbanViewOutput",
    "KanbanViewSettingsInput",
    "KanbanViewSettingsOutput",
    "LegacyIdentity",
    "LegacyIdentityDetails",
    "LineItem",
    "ListTagsResponse",
    "ListToolsResponse",
    "ListTriggersResponse",
    "Mapping",
    "MarkDownWithContext",
    "MarkdownColumn",
    "MarkdownSplitterConfig",
    "McpAuthType",
    "Me",
    "MeUpdate",
    "Mention",
    "MentionParticipant",
    "Message",
    "MessageChunk",
    "ModelProvider",
    "MultiPageCrawlerSettingsInput",
    "MultiPageCrawlerSettingsInputScraper",
    "MultiPageCrawlerSettingsInputTextExtractor",
    "MultiPageCrawlerSettingsOutput",
    "MultiPageCrawlerSettingsOutputScraper",
    "MultiPageCrawlerSettingsOutputTextExtractor",
    "MultiSelectColumn",
    "NodeUi",
    "Notification",
    "NotificationAction",
    "NotificationActionType",
    "NotificationSeverity",
    "NotificationType",
    "NotionFilterBy",
    "NotionFilterOptions",
    "NotionOAuthRequest",
    "NumberColumn",
    "NumberColumnDefault",
    "NumberColumnMaxValue",
    "NumberColumnMinValue",
    "OAuthAuthType",
    "Organization",
    "ParagraphSplitterConfig",
    "Participant",
    "ParticipantType",
    "PeopleColumn",
    "PlaceholderInput",
    "PlaceholderInputType",
    "PlaceholderOutput",
    "PlaceholderOutputType",
    "Plan",
    "PlanTypes",
    "Playwright",
    "PlaywrightWaitForLoadState",
    "Position",
    "Prompt",
    "PromptRole",
    "PublicCopilotConfig",
    "PublicCopilotConfigCodeTheme",
    "PublicCopilotConfigFabValue",
    "PublicCopilotConfigMode",
    "PublicCopilotResponse",
    "PulseFeedResponse",
    "PulseHook",
    "PulseHookInput",
    "PulseTargetConfig",
    "QueryBuilderRequest",
    "QueryBuilderRequestGroupByItem",
    "QueryBuilderRequestSortBy",
    "QueryBuilderRequestSortDirection",
    "QueryBuilderRequestTagMode",
    "QueryRequest",
    "QuerySort",
    "Readability",
    "RecursiveSplitterConfig",
    "RelationColumn",
    "RenameRequest",
    "RenameResponse",
    "ReqBody",
    "RequestBody",
    "Resource",
    "ResourceResourceType",
    "ResponseModelUsage",
    "Result",
    "RotateApiKeysRequest",
    "Rule",
    "RulesInput",
    "RulesOutput",
    "RunLog",
    "RunLogPagination",
    "Schedule",
    "SchemaResponse",
    "SchemasResponse",
    "ScoutHook",
    "ScoutHookConfigHttp",
    "ScoutHookEventDiscriminator",
    "ScoutHookEventDiscriminatorType",
    "ScoutHookEventTrigger",
    "ScoutHookResponse",
    "ScoutHookUpdate",
    "ScoutHookUpdateTriggeringEventsItem",
    "ScoutHooksResponse",
    "ScoutUser",
    "SearchRequest",
    "SearchRequestSearchType",
    "SelectColumn",
    "SelectOptionItem",
    "SentenceSplitterConfig",
    "ServiceInfo",
    "SinglePageCrawlerSettingsInput",
    "SinglePageCrawlerSettingsInputScraper",
    "SinglePageCrawlerSettingsInputTextExtractor",
    "SinglePageCrawlerSettingsOutput",
    "SinglePageCrawlerSettingsOutputScraper",
    "SinglePageCrawlerSettingsOutputTextExtractor",
    "SitemapCrawlerSettingsInput",
    "SitemapCrawlerSettingsInputScraper",
    "SitemapCrawlerSettingsInputTextExtractor",
    "SitemapCrawlerSettingsOutput",
    "SitemapCrawlerSettingsOutputScraper",
    "SitemapCrawlerSettingsOutputTextExtractor",
    "SlackEventResponse",
    "SlackMessageRequest",
    "SlackReactionRequest",
    "SlackTriggerConfigInput",
    "SlackTriggerConfigInputAction",
    "SlackTriggerConfigOutput",
    "SlackTriggerConfigOutputAction",
    "SlackUrlVerification",
    "SortDirection",
    "SourceArchetype",
    "SourceArchetypeIntegrationVersion",
    "SourceSync",
    "SourceSyncCrawlSettingsInput",
    "SourceSyncCrawlSettingsInputMode",
    "SourceSyncCrawlSettingsOutput",
    "SourceSyncCrawlSettingsOutputMode",
    "SourceSyncGoogleDriveSettings",
    "SourceSyncNotionSettingsInput",
    "SourceSyncNotionSettingsOutput",
    "SourceSyncPageCrawlSettingsInput",
    "SourceSyncPageCrawlSettingsInputMode",
    "SourceSyncPageCrawlSettingsOutput",
    "SourceSyncPageCrawlSettingsOutputMode",
    "SourceSyncSitemapSettingsInput",
    "SourceSyncSitemapSettingsInputMode",
    "SourceSyncSitemapSettingsOutput",
    "SourceSyncSitemapSettingsOutputMode",
    "SourceSyncWebsiteSettings",
    "SourceSyncWebsiteSettingsSplitter",
    "SrcAppHttpRoutesBillingBillingHourlyData",
    "SrcAppHttpRoutesBillingBillingHourlyResponse",
    "SrcAppHttpRoutesBillingChangeBillingPlanResponse",
    "SrcAppHttpRoutesBillingCreatePortalSessionData",
    "SrcAppHttpRoutesBillingCreatePortalSessionResponse",
    "SrcAppHttpRoutesBillingFreePlanUsageData",
    "SrcAppHttpRoutesBillingFreePlanUsageResponse",
    "SrcAppHttpRoutesBillingGetBillingData",
    "SrcAppHttpRoutesBillingGetBillingResponse",
    "SrcAppHttpRoutesBillingGetInfoGetInfoResponse",
    "SrcAppHttpRoutesBillingGetInvoicesData",
    "SrcAppHttpRoutesBillingGetInvoicesResponse",
    "SrcAppHttpRoutesBillingGetNotificationsResponse",
    "SrcAppHttpRoutesBillingRenewPlansData",
    "SrcAppHttpRoutesBillingRenewPlansResponse",
    "SrcAppHttpRoutesCollectionCreateCollectionResponse",
    "SrcAppHttpRoutesCollectionCreateSyncResponse",
    "SrcAppHttpRoutesCollectionCreateTableResponse",
    "SrcAppHttpRoutesCollectionDeleteCollectionResponse",
    "SrcAppHttpRoutesCollectionDeleteDocumentsResponse",
    "SrcAppHttpRoutesCollectionDeleteSyncResponse",
    "SrcAppHttpRoutesCollectionDeleteTableResponse",
    "SrcAppHttpRoutesCollectionGetCollectionResponse",
    "SrcAppHttpRoutesCollectionGetCollectionsResponse",
    "SrcAppHttpRoutesCollectionGetDocumentResponse",
    "SrcAppHttpRoutesCollectionGetDocumentsResponse",
    "SrcAppHttpRoutesCollectionGetSyncResponse",
    "SrcAppHttpRoutesCollectionGetSyncsResponse",
    "SrcAppHttpRoutesCollectionGetTableResponse",
    "SrcAppHttpRoutesCollectionGetTablesResponse",
    "SrcAppHttpRoutesCollectionListCollectionSyncsResponseModel",
    "SrcAppHttpRoutesCollectionListSourceArchetypesResponseModel",
    "SrcAppHttpRoutesCollectionParseFileResponse",
    "SrcAppHttpRoutesCollectionSyncTableResponse",
    "SrcAppHttpRoutesCollectionUpdateCollectionResponse",
    "SrcAppHttpRoutesCollectionUpdateDocumentResponse",
    "SrcAppHttpRoutesCollectionUpdateSyncResponse",
    "SrcAppHttpRoutesCollectionUpdateTableResponse",
    "SrcAppHttpRoutesDriveCreateDriveCrawlPayload",
    "SrcAppHttpRoutesDriveCreateDriveCrawlPayloadSourceSyncSettings",
    "SrcAppHttpRoutesDriveGrantAccessPayload",
    "SrcAppHttpRoutesDriveRevokeAccessPayload",
    "SrcAppHttpRoutesInboxHandleMessageIncomingMessage",
    "SrcAppHttpRoutesInboxHandleMessageIncomingMessageContent",
    "SrcAppHttpRoutesInboxHandleMessageIncomingMessageContentType",
    "SrcAppHttpRoutesInboxHandleMessageInteractionRequest",
    "SrcAppHttpRoutesInboxHandleMessageInteractionRequestParticipantsItem",
    "SrcAppHttpRoutesIntegrationMcpConnectMcpPayload",
    "SrcAppHttpRoutesIntegrationMcpExchangeMcpAuthPayload",
    "SrcAppHttpRoutesOnboardingHandleGetMeResponse",
    "SrcAppHttpRoutesOnboardingHandleUpdateMeResponse",
    "SrcAppHttpRoutesRootGetInfoResponse",
    "SrcAppHttpRoutesTagsCreateTagPayload",
    "SrcAppHttpRoutesTagsUpdateTagPayload",
    "SrcAppHttpRoutesTriggerCreateTriggerResponse",
    "SrcAppHttpRoutesWorldInteractIncomingMessage",
    "SrcAppHttpRoutesWorldInteractIncomingMessageContent",
    "SrcAppHttpRoutesWorldInteractIncomingMessageContentItem",
    "SrcAppHttpRoutesWorldInteractInteractionRequest",
    "SrcHandlersCreateCopilotResponse",
    "SrcHandlersCreateWorkflowResponse",
    "SrcHandlersCreateWorkflowRevisionResponse",
    "SrcHandlersDeleteCopilotResponse",
    "SrcHandlersDeleteWorkflowResponse",
    "SrcHandlersDeleteWorkflowRevisionResponse",
    "SrcHandlersGetCopilotResponse",
    "SrcHandlersGetWorkflowEnvironmentsResponse",
    "SrcHandlersGetWorkflowResponse",
    "SrcHandlersListCopilotsResponse",
    "SrcHandlersListWorkflowRevisionsResponse",
    "SrcHandlersListWorkflowsResponse",
    "SrcHandlersPromoteWorkflowRevisionResponse",
    "SrcHandlersUpdateCopilotResponse",
    "SrcHandlersUpdateWorkflowEnvironmentResponse",
    "SrcHandlersUpdateWorkflowResponse",
    "SrcHandlersUpdateWorkflowRevisionResponse",
    "StoreResponse",
    "StripeProvider",
    "StripeProviderMeta",
    "Subscription",
    "Sync",
    "SyncConfigInput",
    "SyncConfigInputSourceSettings",
    "SyncConfigOutput",
    "SyncConfigOutputSourceSettings",
    "Table",
    "TableConfigOutput",
    "TableConfigOutputSchemaItem",
    "TableViewInput",
    "TableViewOutput",
    "TableViewSettingsInput",
    "TableViewSettingsInputRowHeight",
    "TableViewSettingsOutput",
    "TableViewSettingsOutputRowHeight",
    "Tag",
    "TagsResponse",
    "TextExtractor",
    "TextExtractorConfig",
    "TextLongColumn",
    "TextShortColumn",
    "Tool",
    "ToolConfigResource",
    "ToolConfigResourceType",
    "ToolDetails",
    "ToolsData",
    "ToolsResponse",
    "TrafilaturaInput",
    "TrafilaturaInputTrafilaturaType",
    "TrafilaturaOutput",
    "TrafilaturaOutputTrafilaturaType",
    "Trigger",
    "TriggerStatus",
    "TriggerTriggerConfig",
    "TypescriptAutomationConfig",
    "Units",
    "UpdateCronAuthResponse",
    "UpdateEntityRequest",
    "UpdateQuestionnaireFilesRequest",
    "UpdateTagResponse",
    "UpdateTagsRequest",
    "UpdateTriggerResponse",
    "UrlColumn",
    "Usage",
    "UsageTypes",
    "UserIdentity",
    "UserIdentityDetails",
    "UserOrganizationConfig",
    "ValidationError",
    "ValidationErrorLocItem",
    "ViewFilter",
    "ViewListResponse",
    "ViewListResponseDataItem",
    "ViewQueryInput",
    "ViewQueryOutput",
    "ViewResponse",
    "ViewResponseData",
    "ViewStateResponse",
    "ViewVisibility",
    "Workflow",
    "WorkflowActor",
    "WorkflowActorType",
    "WorkflowConfigInput",
    "WorkflowConfigOutput",
    "WorkflowExecute",
    "WorkflowHook",
    "WorkflowHookInput",
    "WorkflowNoteInput",
    "WorkflowNoteOutput",
    "WorkflowRun",
    "WorkflowRunCompleted",
    "WorkflowRunCompletedData",
    "WorkflowRunCompletedEnvironment",
    "WorkflowRunFailed",
    "WorkflowRunFailedData",
    "WorkflowRunFailedEnvironment",
    "WorkflowRunResponse",
    "WorkflowRunStarted",
    "WorkflowRunStartedData",
    "WorkflowRunStartedEnvironment",
    "WorkflowRunStateValue",
    "WorkflowRunStopReason",
    "WorkflowRunStreamResponse",
    "WorkflowTargetConfig",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.slack_event_response import SlackEventResponse
from ...types.slack_url_verification import SlackUrlVerification

TriggersExecuteSlackResponse = typing.Union[SlackUrlVerification, SlackEventResponse]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .workflow_target_config import WorkflowTargetConfig


class WorkflowHookInput(UncheckedBaseModel):
    """
    Input schema for workflow hooks.
    """

    name: str
    description: typing.Optional[str] = None
    target_id: str
    response_mode: typing.Optional[str] = None
    allowed_methods: typing.Optional[typing.List[str]] = None
    max_payload_size: typing.Optional[int] = None
    enable_auth: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether to generate a secret for HMAC authentication
    """

    target_type: typing.Optional[typing.Literal["workflow"]] = None
    target_config: typing.Optional[WorkflowTargetConfig] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .actor_identity import ActorIdentity
from .favorite_item import FavoriteItem
from .flags import Flags
from .user_organization_config import UserOrganizationConfig


class Me(UncheckedBaseModel):
    id: typing.Optional[str] = None
    doc_type: typing.Optional[typing.Literal["user"]] = None
    created_by: ActorIdentity
    updated_by: ActorIdentity
    created_at: typing.Optional[dt.datetime] = None
    updated_at: typing.Optional[dt.datetime] = None
    is_seed: typing.Optional[bool] = None
    first_name: str
    last_name: str
    email_address: str
    inbox_welcome_message_sent: typing.Optional[bool] = None
    consent: typing.Optional[typing.Dict[str, typing.Optional[bool]]] = None
    use_cases: typing.Optional[typing.List[str]] = None
    lead_id: typing.Optional[str] = None
    organizations: typing.Optional[typing.Dict[str, UserOrganizationConfig]] = None
    favorites: typing.Optional[typing.List[FavoriteItem]] = None
    flags: Flags
    permissions: typing.Optional[typing.Dict[str, bool]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class QueryRequest(UncheckedBaseModel):
    """
    Query request - declarative filtering
    """

    type: typing.Optional[str] = pydantic.Field(default=None)
    """
    Filter by entity type
    """

    filter: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Filter by data fields
    """

    tags: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Filter by tags (must have ALL specified tags)
    """

    limit: typing.Optional[int] = pydantic.Field(default=None)
    """
    Max results
    """

    include_deleted: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include soft-deleted entities
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .collection_config import CollectionConfig
from .legacy_identity import LegacyIdentity


class Collection(UncheckedBaseModel):
    collection_config: CollectionConfig
    last_updated_at: dt.datetime
    created_at: dt.datetime
    created_by: LegacyIdentity
    last_updated_by: LegacyIdentity
    collection_id: str
    revision_id: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.action_type import ActionType
from ..types.delete_trigger_response import DeleteTriggerResponse
from ..types.execute_trigger_response import ExecuteTriggerResponse
from ..types.list_triggers_response import ListTriggersResponse
from ..types.src_app_http_routes_trigger_create_trigger_response import SrcAppHttpRoutesTriggerCreateTriggerResponse
from ..types.update_cron_auth_response import UpdateCronAuthResponse
from ..types.update_trigger_response import UpdateTriggerResponse
from .raw_client import AsyncRawTriggersClient, RawTriggersClient
from .types.triggers_create_request import TriggersCreateRequest
from .types.triggers_execute_slack_response import TriggersExecuteSlackResponse
from .types.triggers_update_request import TriggersUpdateRequest

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class TriggersClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawTriggersClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawTriggersClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawTriggersClient
        """
        return self._raw_client

    def list(
        self,
        *,
        action_type: typing.Optional[ActionType] = None,
        workflow_id: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ListTriggersResponse:
        """
        All apis and effects are injected into every endpoint
        via request.context. The request_context() utility can be used
        to get Intellisense type-completion

        Parameters
        ----------
        action_type : typing.Optional[ActionType]
            Filter by action type

        workflow_id : typing.Optional[str]
            Filter by workflow ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ListTriggersResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.triggers.list(
            action_type="workflow.execute",
            workflow_id="workflow_id",
        )
        """
        _response = self._raw_client.list(
            action_type=action_type, workflow_id=workflow_id, request_options=request_options
        )
        return _response.data

    def create(
        self, *, request: TriggersCreateRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcAppHttpRoutesTriggerCreateTriggerResponse:
        """
        Parameters
        ----------
        request : TriggersCreateRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesTriggerCreateTriggerResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout, SlackTriggerConfigInput, SourceSync

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.triggers.create(
            request=SlackTriggerConfigInput(
                action=SourceSync(
                    sync_id="sync_id",
                ),
            ),
        )
        """
        _response = self._raw_client.create(request=request, request_options=request_options)
        return _response.data

    def update(
        self,
        trigger_id: str,
        *,
        request: TriggersUpdateRequest,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UpdateTriggerResponse:
        """
        Parameters
        ----------
        trigger_id : str

        request : TriggersUpdateRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UpdateTriggerResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout, SlackTriggerConfigInput, SourceSync

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.triggers.update(
            trigger_id="trigger_id",
            request=SlackTriggerConfigInput(
                action=SourceSync(
                    sync_id="sync_id",
                ),
            ),
        )
        """
        _response = self._raw_client.update(trigger_id, request=request, request_options=request_options)
        return _response.data

    def delete(
        self, trigger_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DeleteTriggerResponse:
        """
        Parameters
        ----------
        trigger_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteTriggerResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.triggers.delete(
            trigger_id="trigger_id",
        )
        """
        _response = self._raw_client.delete(trigger_id, request_options=request_options)
        return _response.data

    def execute_slack(self, *, request_options: typing.Optional[RequestOptions] = None) -> TriggersExecuteSlackResponse:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TriggersExecuteSlackResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.triggers.execute_slack()
        """
        _response = self._raw_client.execute_slack(request_options=request_options)
        return _response.data

    def execute_cron(self, *, request_options: typing.Optional[RequestOptions] = None) -> ExecuteTriggerResponse:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ExecuteTriggerResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.triggers.execute_cron()
        """
        _response = self._raw_client.execute_cron(request_options=request_options)
        return _response.data

    def update_cron_auth_headers(
        self,
        *,
        dry_run: typing.Optional[bool] = None,
        test_org_id: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UpdateCronAuthResponse:
        """
        Update Cloud Scheduler job Authorization headers for organizations.
        Lists all Cloud Scheduler jobs and updates those matching the trigger pattern.

        Args:
            dry_run: If True, only shows what would be updated without making changes
            test_org_id: If provided, only processes jobs for this specific organization ID

        Only accessible to Scout internal organizations for security.

        Parameters
        ----------
        dry_run : typing.Optional[bool]

        test_org_id : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UpdateCronAuthResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.triggers.update_cron_auth_headers(
            dry_run=True,
            test_org_id="test_org_id",
        )
        """
        _response = self._raw_client.update_cron_auth_headers(
            dry_run=dry_run, test_org_id=test_org_id, request_options=request_options
        )
        return _response.data


class AsyncTriggersClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawTriggersClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawTriggersClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawTriggersClient
        """
        return self._raw_client

    async def list(
        self,
        *,
        action_type: typing.Optional[ActionType] = None,
        workflow_id: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ListTriggersResponse:
        """
        All apis and effects are injected into every endpoint
        via request.context. The request_context() utility can be used
        to get Intellisense type-completion

        Parameters
        ----------
        action_type : typing.Optional[ActionType]
            Filter by action type

        workflow_id : typing.Optional[str]
            Filter by workflow ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ListTriggersResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.triggers.list(
                action_type="workflow.execute",
                workflow_id="workflow_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(
            action_type=action_type, workflow_id=workflow_id, request_options=request_options
        )
        return _response.data

    async def create(
        self, *, request: TriggersCreateRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcAppHttpRoutesTriggerCreateTriggerResponse:
        """
        Parameters
        ----------
        request : TriggersCreateRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesTriggerCreateTriggerResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout, SlackTriggerConfigInput, SourceSync

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.triggers.create(
                request=SlackTriggerConfigInput(
                    action=SourceSync(
                        sync_id="sync_id",
                    ),
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(request=request, request_options=request_options)
        return _response.data

    async def update(
        self,
        trigger_id: str,
        *,
        request: TriggersUpdateRequest,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UpdateTriggerResponse:
        """
        Parameters
        ----------
        trigger_id : str

        request : TriggersUpdateRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UpdateTriggerResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout, SlackTriggerConfigInput, SourceSync

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.triggers.update(
                trigger_id="trigger_id",
                request=SlackTriggerConfigInput(
                    action=SourceSync(
                        sync_id="sync_id",
                    ),
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(trigger_id, request=request, request_options=request_options)
        return _response.data

    async def delete(
        self, trigger_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> DeleteTriggerResponse:
        """
        Parameters
        ----------
        trigger_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteTriggerResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.triggers.delete(
                trigger_id="trigger_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(trigger_id, request_options=request_options)
        return _response.data

    async def execute_slack(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> TriggersExecuteSlackResponse:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TriggersExecuteSlackResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.triggers.execute_slack()


        asyncio.run(main())
        """
        _response = await self._raw_client.execute_slack(request_options=request_options)
        return _response.data

    async def execute_cron(self, *, request_options: typing.Optional[RequestOptions] = None) -> ExecuteTriggerResponse:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ExecuteTriggerResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.triggers.execute_cron()


        asyncio.run(main())
        """
        _response = await self._raw_client.execute_cron(request_options=request_options)
        return _response.data

    async def update_cron_auth_headers(
        self,
        *,
        dry_run: typing.Optional[bool] = None,
        test_org_id: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> UpdateCronAuthResponse:
        """
        Update Cloud Scheduler job Authorization headers for organizations.
        Lists all Cloud Scheduler jobs and updates those matching the trigger pattern.

        Args:
            dry_run: If True, only shows what would be updated without making changes
            test_org_id: If provided, only processes jobs for this specific organization ID

        Only accessible to Scout internal organizations for security.

        Parameters
        ----------
        dry_run : typing.Optional[bool]

        test_org_id : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        UpdateCronAuthResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.triggers.update_cron_auth_headers(
                dry_run=True,
                test_org_id="test_org_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update_cron_auth_headers(
            dry_run=dry_run, test_org_id=test_org_id, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .field_mapping import FieldMapping


class WorkflowTargetConfig(UncheckedBaseModel):
    """
    Configuration specific to workflow targets.
    """

    field_mappings: typing.Optional[typing.List[FieldMapping]] = pydantic.Field(default=None)
    """
    Map webhook data fields to workflow input fields
    """

    default_field_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Default field to receive full webhook payload if no mappings match
    """

    run_mode: typing.Optional[str] = pydantic.Field(default=None)
    """
    How to run the workflow: async or sync
    """

    timeout_seconds: typing.Optional[int] = pydantic.Field(default=None)
    """
    Timeout for sync execution
    """

    verify_token: typing.Optional[str] = pydantic.Field(default=None)
    """
    Token for webhook verification (e.g., Meta hub.verify_token)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from .raw_client import AsyncRawOrganizationsClient, RawOrganizationsClient


class OrganizationsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawOrganizationsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawOrganizationsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawOrganizationsClient
        """
        return self._raw_client

    def delete_integration(
        self, integration_type: str, integration_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Dict[str, str]:
        """
        Parameters
        ----------
        integration_type : str

        integration_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Dict[str, str]
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.organizations.delete_integration(
            integration_type="integration_type",
            integration_id="integration_id",
        )
        """
        _response = self._raw_client.delete_integration(
            integration_type, integration_id, request_options=request_options
        )
        return _response.data


class AsyncOrganizationsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawOrganizationsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawOrganizationsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawOrganizationsClient
        """
        return self._raw_client

    async def delete_integration(
        self, integration_type: str, integration_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Dict[str, str]:
        """
        Parameters
        ----------
        integration_type : str

        integration_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Dict[str, str]
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.organizations.delete_integration(
                integration_type="integration_type",
                integration_id="integration_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete_integration(
            integration_type, integration_id, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .column_type import ColumnType
from .data_type import DataType
from .typescript_automation_config import TypescriptAutomationConfig


class ColumnTypeBase(UncheckedBaseModel):
    column_id: typing.Optional[str] = None
    column_display_name: typing.Optional[str] = None
    column_type: ColumnType
    data_type: DataType
    hidden: typing.Optional[bool] = None
    automation_config: TypescriptAutomationConfig = pydantic.Field()
    """
    Optional automation configuration to automatically calculate values for this column
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class EntityQueryRequest(UncheckedBaseModel):
    """
    Query for entities (agents or objects)
    """

    entity_type: typing.Optional[str] = pydantic.Field(default=None)
    """
    'agent' or 'object'
    """

    activity_filters: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Filter activities that entities appear in
    """

    tags: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Activities must have these tags
    """

    outcomes: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Activities must have these outcomes
    """

    actions: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Activities must have these actions
    """

    time: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Time range for activities
    """

    kinds: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Entity kinds to include (user, team, document, etc)
    """

    roles: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Entity roles to include
    """

    current_state: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Return only current state via quantum collapse
    """

    include_stats: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include activity statistics for each entity
    """

    group_by: typing.Optional[str] = pydantic.Field(default=None)
    """
    Group entities by field (kind, role)
    """

    limit: typing.Optional[int] = None
    min_activities: typing.Optional[int] = pydantic.Field(default=None)
    """
    Minimum activities for entity to be included
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.src_handlers_update_workflow_revision_response import SrcHandlersUpdateWorkflowRevisionResponse
from .raw_client import AsyncRawWorkflowRevisionsClient, RawWorkflowRevisionsClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class WorkflowRevisionsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawWorkflowRevisionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawWorkflowRevisionsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawWorkflowRevisionsClient
        """
        return self._raw_client

    def update(
        self,
        workflow_id: str,
        revision_id: str,
        *,
        name: str,
        description: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SrcHandlersUpdateWorkflowRevisionResponse:
        """
        Parameters
        ----------
        workflow_id : str

        revision_id : str

        name : str

        description : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcHandlersUpdateWorkflowRevisionResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.workflow_revisions.update(
            workflow_id="workflow_id",
            revision_id="revision_id",
            name="name",
        )
        """
        _response = self._raw_client.update(
            workflow_id, revision_id, name=name, description=description, request_options=request_options
        )
        return _response.data


class AsyncWorkflowRevisionsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawWorkflowRevisionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawWorkflowRevisionsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawWorkflowRevisionsClient
        """
        return self._raw_client

    async def update(
        self,
        workflow_id: str,
        revision_id: str,
        *,
        name: str,
        description: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SrcHandlersUpdateWorkflowRevisionResponse:
        """
        Parameters
        ----------
        workflow_id : str

        revision_id : str

        name : str

        description : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcHandlersUpdateWorkflowRevisionResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.workflow_revisions.update(
                workflow_id="workflow_id",
                revision_id="revision_id",
                name="name",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(
            workflow_id, revision_id, name=name, description=description, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

from .documents_create_request_body_item_value import DocumentsCreateRequestBodyItemValue
from .documents_create_request_body_one_value import DocumentsCreateRequestBodyOneValue
from .documents_create_request_body_zero_value import DocumentsCreateRequestBodyZeroValue

DocumentsCreateRequestBody = typing.Union[
    typing.Dict[str, DocumentsCreateRequestBodyZeroValue],
    typing.Dict[str, typing.Optional[DocumentsCreateRequestBodyOneValue]],
    typing.List[typing.Dict[str, DocumentsCreateRequestBodyItemValue]],
    typing.List[typing.Dict[str, typing.Optional[DocumentsCreateRequestBodyItemValue]]],
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .rules_input import RulesInput
from .slack_trigger_config_input_action import SlackTriggerConfigInputAction
from .trigger_status import TriggerStatus


class SlackTriggerConfigInput(UncheckedBaseModel):
    trigger_display_name: typing.Optional[typing.Literal["When message is sent to Slack Channel"]] = None
    trigger_type: typing.Optional[typing.Literal["slack.message"]] = None
    action: SlackTriggerConfigInputAction
    status: typing.Optional[TriggerStatus] = None
    run_conditions: typing.Optional[RulesInput] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .block_output import BlockOutput
from .placeholder_output import PlaceholderOutput
from .workflow_note_output import WorkflowNoteOutput


class WorkflowConfigOutput(UncheckedBaseModel):
    workflow_display_name: typing.Optional[str] = None
    workflow_schema_version: typing.Optional[str] = None
    workflow_img_url: typing.Optional[str] = None
    workflow_description: typing.Optional[str] = None
    blocks: typing.Optional[typing.List[BlockOutput]] = None
    notes: typing.Optional[typing.List[WorkflowNoteOutput]] = None
    placeholders: typing.Optional[typing.List[PlaceholderOutput]] = None
    tags: typing.Optional[typing.List[str]] = None
    is_tool: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class PulseTargetConfig(UncheckedBaseModel):
    """
    Configuration specific to pulse channel targets.
    """

    channel_tags: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Tags that route this pulse to specific channels
    """

    content_field: typing.Optional[str] = pydantic.Field(default=None)
    """
    JSONPath to extract TipTap content (defaults to $.content)
    """

    text_field: typing.Optional[str] = pydantic.Field(default=None)
    """
    JSONPath to extract plain text (defaults to $.text)
    """

    tags_field: typing.Optional[str] = pydantic.Field(default=None)
    """
    JSONPath to extract additional tags (defaults to $.tags)
    """

    default_visibility: typing.Optional[str] = pydantic.Field(default=None)
    """
    Default visibility for pulses: private, team, or public
    """

    append_channel_tags: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether to append channel tags to webhook-provided tags
    """

    agent_type: typing.Optional[str] = pydantic.Field(default=None)
    """
    Type of agent creating the pulse: user, service, bot, system
    """

    agent_name_field: typing.Optional[str] = pydantic.Field(default=None)
    """
    JSONPath to extract agent name, or static value
    """

    auto_format_json: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Auto-format JSON payloads as code blocks in TipTap
    """

    include_metadata: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include webhook metadata (headers, timestamp) in pulse
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

FilterOperator = typing.Union[
    typing.Literal[
        "equals",
        "not_equals",
        "contains",
        "not_contains",
        "starts_with",
        "ends_with",
        "is_empty",
        "is_not_empty",
        "greater_than",
        "less_than",
        "greater_than_or_equal",
        "less_than_or_equal",
        "between",
        "in",
        "not_in",
        "date_is",
        "date_before",
        "date_after",
        "date_between",
        "date_is_empty",
        "date_is_not_empty",
        "is_true",
        "is_false",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class Flags(UncheckedBaseModel):
    """
    On top of feature flags fetched from our port, we can also have other flags that
    are derived solely from business logic. This is where we would add those.
    """

    automation_columns: typing.Optional[bool] = None
    display_scout_organization_id: typing.Optional[bool] = None
    inbox_agent_trace: typing.Optional[bool] = None
    multi_player_chat: typing.Optional[bool] = None
    team_workspace: typing.Optional[bool] = None
    token_counts: typing.Optional[bool] = None
    drive_integrations: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .agent_target_config import AgentTargetConfig


class AgentHook(UncheckedBaseModel):
    """
    Hook model for agent targets (future).
    """

    id: str
    organization_id: str
    name: str
    description: typing.Optional[str] = None
    target_id: str
    status: typing.Optional[str] = None
    response_mode: typing.Optional[str] = None
    allowed_methods: typing.Optional[typing.List[str]] = None
    max_payload_size: typing.Optional[int] = None
    secret: typing.Optional[str] = None
    url: typing.Optional[str] = None
    created_at: dt.datetime
    updated_at: dt.datetime
    created_by: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    target_type: typing.Optional[typing.Literal["agent"]] = None
    target_config: AgentTargetConfig

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .sitemap_crawler_settings_input import SitemapCrawlerSettingsInput
from .source_sync_sitemap_settings_input_mode import SourceSyncSitemapSettingsInputMode


class SourceSyncSitemapSettingsInput(UncheckedBaseModel):
    source_archetype_id: typing.Literal["com.scoutos.sitemap"] = "com.scoutos.sitemap"
    sitemap_url: str = pydantic.Field()
    """
    The URL of the sitemap to be crawled.
    """

    crawler_settings: typing.Optional[SitemapCrawlerSettingsInput] = None
    mode: typing.Optional[SourceSyncSitemapSettingsInputMode] = pydantic.Field(default=None)
    """
    Merge: upsert documents keying off site url. Replace: merge and remove stale documents.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .fluent_query_request_with_item import FluentQueryRequestWithItem


class FluentQueryRequest(UncheckedBaseModel):
    """
    Fluent query request - powerful, declarative querying.

    Example:
        {
            "select": "deal",
            "where": [
                {"field": "stage", "operator": "in", "value": ["negotiation", "proposal"]},
                {"field": "value", "operator": ">=", "value": 50000}
            ],
            "with": ["account", "contact"],
            "orderBy": [{"field": "value", "direction": "desc"}],
            "limit": 50
        }
    """

    select: str = pydantic.Field()
    """
    Entity type to select
    """

    where: typing.Optional[typing.List[typing.Dict[str, typing.Optional[typing.Any]]]] = pydantic.Field(default=None)
    """
    WHERE conditions: [{field, operator, value}, ...]
    """

    with_: typing_extensions.Annotated[
        typing.Optional[typing.List[FluentQueryRequestWithItem]], FieldMetadata(alias="with")
    ] = pydantic.Field(default=None)
    """
    Relations to include (auto-JOIN)
    """

    order_by: typing_extensions.Annotated[
        typing.Optional[typing.List[typing.Dict[str, str]]], FieldMetadata(alias="orderBy")
    ] = pydantic.Field(default=None)
    """
    Order by: [{field, direction}, ...]
    """

    limit: typing.Optional[int] = pydantic.Field(default=None)
    """
    Max results
    """

    offset: typing.Optional[int] = pydantic.Field(default=None)
    """
    Offset for pagination
    """

    cursor: typing.Optional[str] = pydantic.Field(default=None)
    """
    Cursor for pagination
    """

    count: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include total count
    """

    group_by: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="groupBy")] = pydantic.Field(
        default=None
    )
    """
    Group by field
    """

    aggregations: typing.Optional[typing.Dict[str, typing.Dict[str, str]]] = pydantic.Field(default=None)
    """
    Aggregations: {alias: {function, field}}
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

ColumnType = typing.Union[
    typing.Literal[
        "checkbox",
        "json",
        "number",
        "select",
        "multi-select",
        "text-long",
        "text-short",
        "datetime",
        "url",
        "markdown",
        "relation",
        "people",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

from .cron_trigger_config import CronTriggerConfig
from .slack_trigger_config_output import SlackTriggerConfigOutput

TriggerTriggerConfig = typing.Union[CronTriggerConfig, SlackTriggerConfigOutput]



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.src_handlers_delete_workflow_revision_response import SrcHandlersDeleteWorkflowRevisionResponse
from ..types.src_handlers_list_workflow_revisions_response import SrcHandlersListWorkflowRevisionsResponse
from ..types.src_handlers_promote_workflow_revision_response import SrcHandlersPromoteWorkflowRevisionResponse
from .raw_client import AsyncRawRevisionsClient, RawRevisionsClient


class RevisionsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawRevisionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawRevisionsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawRevisionsClient
        """
        return self._raw_client

    def delete(
        self, workflow_id: str, revision_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcHandlersDeleteWorkflowRevisionResponse:
        """
        Parameters
        ----------
        workflow_id : str

        revision_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcHandlersDeleteWorkflowRevisionResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.revisions.delete(
            workflow_id="workflow_id",
            revision_id="revision_id",
        )
        """
        _response = self._raw_client.delete(workflow_id, revision_id, request_options=request_options)
        return _response.data

    def list(
        self, workflow_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcHandlersListWorkflowRevisionsResponse:
        """
        List all app revisions in the organization

        Parameters
        ----------
        workflow_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcHandlersListWorkflowRevisionsResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.revisions.list(
            workflow_id="workflow_id",
        )
        """
        _response = self._raw_client.list(workflow_id, request_options=request_options)
        return _response.data

    def update(
        self, workflow_id: str, revision_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcHandlersPromoteWorkflowRevisionResponse:
        """
        Parameters
        ----------
        workflow_id : str

        revision_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcHandlersPromoteWorkflowRevisionResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.revisions.update(
            workflow_id="workflow_id",
            revision_id="revision_id",
        )
        """
        _response = self._raw_client.update(workflow_id, revision_id, request_options=request_options)
        return _response.data


class AsyncRevisionsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawRevisionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawRevisionsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawRevisionsClient
        """
        return self._raw_client

    async def delete(
        self, workflow_id: str, revision_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcHandlersDeleteWorkflowRevisionResponse:
        """
        Parameters
        ----------
        workflow_id : str

        revision_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcHandlersDeleteWorkflowRevisionResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.revisions.delete(
                workflow_id="workflow_id",
                revision_id="revision_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(workflow_id, revision_id, request_options=request_options)
        return _response.data

    async def list(
        self, workflow_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcHandlersListWorkflowRevisionsResponse:
        """
        List all app revisions in the organization

        Parameters
        ----------
        workflow_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcHandlersListWorkflowRevisionsResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.revisions.list(
                workflow_id="workflow_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(workflow_id, request_options=request_options)
        return _response.data

    async def update(
        self, workflow_id: str, revision_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcHandlersPromoteWorkflowRevisionResponse:
        """
        Parameters
        ----------
        workflow_id : str

        revision_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcHandlersPromoteWorkflowRevisionResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.revisions.update(
                workflow_id="workflow_id",
                revision_id="revision_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(workflow_id, revision_id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

from .scout_hook_event_trigger import ScoutHookEventTrigger

ScoutHookUpdateTriggeringEventsItem = typing.Union[typing.Literal["agent.interaction.responded"], ScoutHookEventTrigger]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .search_request_search_type import SearchRequestSearchType


class SearchRequest(UncheckedBaseModel):
    """
    Search request model
    """

    query: typing.Optional[str] = pydantic.Field(default=None)
    """
    Search query text
    """

    search_type: typing.Optional[SearchRequestSearchType] = pydantic.Field(default=None)
    """
    Type of search
    """

    filters: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Additional filters to apply
    """

    limit: typing.Optional[int] = pydantic.Field(default=None)
    """
    Maximum results to return
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .notion_filter_options import NotionFilterOptions


class SourceSyncNotionSettingsOutput(UncheckedBaseModel):
    source_archetype_id: typing.Literal["com.notion.notion"] = "com.notion.notion"
    api_key: typing.Optional[str] = pydantic.Field(default=None)
    """
    The API key used for authentication with Notion.
    """

    filter_options: typing.Optional[typing.List[NotionFilterOptions]] = pydantic.Field(default=None)
    """
    Narrow down pages you sync from Notion by page URL or page title.
    For example, you can search for page titles like 'blog' and filter out pages with titles containing 'faq'
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
